
# q-expansion of newform 2.82.a.b, downloaded from the LMFDB on 27 April 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 2
weight = 82
poly_data = [15227343706090890463549797596060496062977217468321124839077527200, -1502772308966385407243870196944706973427347215700, -376262508638451474994292856206343, -2, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0], 1], [[-960, 1920, 0, 0], 1], [[-3068985417985209724798726201550810822959831937964908616640, 394650807354726094215039393568006977804160, 27683303009004195755745280, -1897922560], 35413484788106991144400323933], [[-820674277774218300967859756654645837418612775903039903512455680, 342164290928400366156726594216579624370054435840, 12867168353563916791387697889280, -1419635992821760], 35413484788106991144400323933]]

hecke_ring_character_values = None
aps_data = [[1099511627776, 0, 0, 0], [-1777934344659239676, -1, 0, 0], [6228291992559675893012816070, 181291919, 1, 0], [4598222899259408521235848030813448, -6509551465304, -103354, -1], [823375604978615018132267977205004322805772, 23001568593131406957921, -34705923827652, -61258538], [141802411696168386597888073986702807345349454, -7191847897731357877812105, -1277062033641831, -56391928264], [4272474488091544742009909071452642375988661026578, 372832727135235319989538414106, 3060493895907796942918, -420103945989308], [1439241482941602542082329185148548769362300490069780, 35502124006265855376020251772503, 152846607080160712518212, 162750783707526378], [4911651170806691235811329421139999833818122029162187544, 229894969987143872495671925157393312, 51014831632077430727972586, 426417988348039108409], [22474796087512023098760775545736118103618864410018768685150, -9001163680537167227223003465502688473045, 1026035010658389426445219416997, -4175384348653558930518432], [1107537085310180828581193361822916314841881791839415637150752, -66270705379896999811398830956302990325592, 19594574900630856167392744875728, -35768133109977905591805368], [717090492055879860148711432635614091574959570571771492778055398, 86816398003205804789490667299923749153195251, -107342094997593228222488265381734307, -38983998305623714320411864008], [60446356868803975261826998456811562748670971401222436132626852522, -3470297299992635680502376334520988365512261596, 6434691312382937420812891322905432476, -3468355870600246335566243310056], [976660197521993178599879281531767674190304323380885218292208092204, -27046155018387827571425578109633068945311941715, -6478396641225311499684064560234683064, 46038031655340645738715292124084], [17037681914878238031543328646743831603421298179246297573473332810288, 44975170183481472426758701524852460148284058504, 92074729495885024759360481856839993932, 472311278038477789383256487616158], [-3126121869427621081517393359458668457018911112546084952665282596765706, 228399959152366676017679968863104031605960301377507, -25972604269921661081183403297466212496787, -266632429572324554215937944524782328], [122411096459657670113448258766227723481040312550194470703440321698762300, 7907152867822459840031204842312613813086968425911745, -20175799187749362431541493944963884256651536, -6538212093431803555943962599001356584], [341675566247041290090569473349454290361637698091567896005294215981477502, 39115039939094599474629494564607285037050548392768271, 5789805994169965750034341207185357787136641, -4491190658585316281405993009174571496], [-34715668612815879074534617166902670085040614058212937426321877588085031612, -2560939126580462288380679004083772892514475462188875125, 321592722764542794394760966165612965741635972, -1936266988615487023013959441135376670582], [132672658924453568915149957385156916109987656331730330171648969512649360712, 5067954098823105656942147363229540589550981221788525632, -45010538368985214424835453525654791285704243362, -13312556293656306250067753950346774528453], [1205162880841388469088522503662995474850582909318546627953101872098423962314, -8389143540909327132446589293033582167515657578230218158, 77507455127315275764471773117655082240446616718, 17822929179628338858916757002831843682692], [-12662117609628526071618728477277016490408617243838594495601996446980960534960, -562147515854170075659607322730027423271184106014088316016, -141067184091173441587138446409250158254861648196, 3217124958165448015303181719553466531655926], [-59630026838202974521116853871363290880681536403144220165256763396502745708716, -11380929376179040424524325989174168591750106566144277652181, -17724510353264460204887421987306049369627337584832, 8191131711602102072982738548174825151519392], [6857011275069597121603216000242857173334712320249035446927674301400777020796890, -78592293469606590338600514393759489971810234767582670641390, -38186437926841093185883847861104748648273882188850, 386875857099216426039598184435965529057858500], [-38668870118280824083204963947589974478069118234517612016727934214000055713228702, -2446205314563711047381997832690087329345590054180974562891454, -6718224578987192685547969690631520793086891792190818, 13201560245205007781741290139294231354966460308], [1028840499023248290389762682857890977560827189211497690525899384251016762918732582, 23345988901466677369898744710832512731172155825539446998878075, 3192684538057998591463616112476983152868014875897173, 51052440914751909007520770371967845875354139112], [-780687524546881432294383891895006237822202186950864001416249384216350411013574296, -80389365701168178425241117000484675143518319629491526062993120, -82253574307159288223732325571286374735965328399983050, -164299171272253973185195428705490570841815448425], [-13285260805166054260670569821512195621208101321925463051205641703514297520209300372, -73110365284148397389417224642958119972793010730383312538833631, 219542342004968218919269776849644427165457725248662180, 156649318697511587667065378557552632563742190170], [-18816906391019679019778273335991123902165157434995338484327552706519050030444784210, 666888546049919534945716240502705600643592394011072294395004643, 1085477300052945257109758404353897059334436298458041709, -806594054926271753523810459319853889318858212704], [-77285814285532604862404164013442489612863525945510100834930109570146842822007194766, -2332849035880292027460440066262992867251669688153341055729839568, -438416029632877509030114971337536783574282748646231344, 5349884687095711112709119808915374775709471363264], [11155550194887728265553426326812869672329404617266038569705236242462568775759216312448, -87130754609651999543924394256148342602965608118454216847526171096, -553520820702349866172863310594941455955969527981002632840, 23775555702810083193999616667120634716516623060140], [-11940959094593197755475673217389303460268372616109521171606097594818099528869106584188, 1819169098055996263502675434991819175565082806171933149128993510627, 356228776117990428678625393967972728272251463364784754652, 264434542901030015943269418361697836698224517668838], [-123292236757010011632041277791757192825872915547349918965190413506686129404310585407222, 10899231496922046610664592023802723315925965121703899559030246548372, 7914561135280998746441067139173607861094232274280149749548, -4325420943563722731077979557955826843327251447018088], [-505086813327030438873321535354298739498133787086102442983883568374648879545214343720820, 17033987157266113136914300282209358291016253997450739735368031259845, -2740526682185425051955737509571280601713672886035143767656, 3184373730778329711653259894764838947611205050483836], [3020699368370458400006824346781234917425229555011864179225979460686035834131843100312150, 196105503751985388115347032970077977068541283818473053642295775014031, 239222916320813189620315646673563437340560334324973853156097, -235889292070852495693112857812290376377795110926823632], [-486312030527727475200232549813341281236010200192155140983389640135258602336838226822248, 201454800697236016890407449788360282807531237975000526966661353698560, -775146026206776215163829278242753768571186479056427564434070, 393845551378310497996527873352788083287074303485031545], [6677550131833329940598062710626515457130039077856339620730209502165423592863301329407198, -1788300002657080440894000946849037260561684519684063036354196184624649, 963242654426775356139857134402886361900268682852793974041, -4307946195701606171244293848387806104181469060450339096], [-385416062242898398794592407496912480125540537723475956529340884409170101692128793144159836, 914416474824332560845025936899515883750357179080420790017624374786111, -728837745547961079103435458729000246758565490477205531658408, -4126111547400464741749239394741499489519400203735119652], [-113962597673786515181226557954751589399794832089120212479149538729637868331674365854836312, 10052546284304917543781537357381592976586662501789351729051974236569448, 45485652351385655105779111785734134892325825636545814553977118, -35074724212471290940955188883363315412135549239715367333], [1034741606157767504233118381537032315683386031472384156776286611490733283443098707608827374, 58127113424298379729038968509334102179431014562182278160043379454373615, 20200507406078195123271709433945429585405906603288781505045665, 137668761959258397190071174134475358643451049654466102760], [-10232011510282261516533334988893772141019441103102803650377042192609210355370120001246628940, -515070899458919217675692017672292700461962660136342194670395656152065621, 768110609373810538056393017874760822991806494171021579901192936, 186138541912946372681433455156975983348430506849079977284], [-94535801315163639094474245867674333647235223677789876357552791579768618263979660765500298, -458615171718345518598064514509154228991126611983810133375029076392658569, 348077299598036587397173595230925755129017196831128459909312409, -134716961473668235995711563764611522323775774258715720704], [-248619758107020058265646637648903315418511686715568299571755150223215777821789858148215899968, -1136234192852983890995365340652521105353018134619721341235715435289017688, -6362129668290390682292802110401754707063888897415439540365687192, -3803663142456780112727381984859738759181973834489898855548], [-13422211193026211156154811689457546057295810830915166377254694126560201021564411214131878206, 4880849204197541586704613194040947835189297129531551943906544688386321426, 3407835897730760213013111004242336219656035577118284397176111822, -15649230047425793442822474875366449735181816871629032569932], [-263453745463410856704920996451195332476240428856930872690978636469051015869254342571428354682, 3634738279481860810420444844877546480967983229417307361240848126349349095, 8977568051773873435584328561672440759103497554506877647538672937, 28333949138655103732657145317730703785149766767986281384528], [659726134344106703998027013940241216562716603536517068935479925445753350176122859232699147720, -23245663861362119813422102556880865273183517889577428628317273702874047688, 2784455562239624860493895391061065910109894469100745660530554246, -15863355292287785032999914094194518755786955081833470018401], [-1450212005001358286930981888388247221261864704780093086657916726959545699903735422838336518188, 145238869026378985782946227639938764643689402739334885641072482338964934851, -82175425480427605651542613916108693612776611054090045246812567608, 469792654139363469202600756150911528214753047960041745951348], [92667899145623588991103562564611403585544143069381832915762331771597235368790935900970739963104, 338755068960554102416505937780130778767231879995138407904006426321481268696, -2072358122512819926613755014132291251206719318418893298003956677520, -4941457943168857657610092070574842580428215021729411905008680], [156035998080490717341568170569243251239577651455382869529009512168857721141196447262906266364388, 484013784933155704645627124446956853225401266147839123074957605855604518215, 6706102585955252661096987632594774447890833265214771920758084718976, 5202100470048459675589964106364047302548724605053391088100544], [124113133388841434914028379952614604969854610630911476284753726920262025703221761197767203112870, 10566682055726911814410659337834397274373419129737913633647843786386380240007, -4047667757397685133863357117241466932820791245491906360709064388727, -4905638267085028060509837508599659323905017353300515035092688], [285761869952553971559706167575020333142809022247640682337409488290453819123311047942786793925994, 15954193717114545308866388109031454342891658753193787001022344568120339315170, -527532752022561506911862348682322645681977243366134257921361677314, 27600912460543696561223917322454389834909553088213801797101284], [-1317944004369583209147809219462489314646056989308647146794951388861151735118336836712732549936400, -35349993260264738710443909750117070185806453018400732669435312727668497197104, -26919546053126014713181987226809613794792867408564618405295842668012, -29803629662200186290128329223306900425834557899658974545543278], [-3953575733938303457704964061479681477570200781033675613472403568628274653810243215647112212601358, -15402848912619507999832972328514080936059191517758691003591928326634343882758, -15576976736331528082377963940960245920817911437329662523753856380826, 2135127026238713386058736632647364111922543578866541299154756], [2221060040692019177008534306034407805940050470147182872234175096469490162283730070397944866137852, -156621160432683774757291804561661256466391229176987588814558093163354627992687, -408069182773474858764531636736706123640066450788885854795639148327184, 301106552610877269321663193041560034658962319535697860457484504], [29679738584055769041692710004472679480010496563406542531196779428636631885691422748541323582198018, 1190635667784492535056014054619389288235901658522174386174369472476152777036992, -393543058606419060089865899613999439597421294338109589851176017225920, -376127501320274883955271716333969386880595622575820053127059680], [-21532830746223652580696988107613964819145514116902148585766306355927987451806247378449937421668856, 2496100236838186998903829254752903383970867007024634889724407968475801050348496, 1386850631235863761405487092328678477219851033164048208327510385000350, -948851629332505351043175335266442311287619288257257886798729125], [-3373560753443867997055211506500683528518139151992861214903912636107441572834676767603990680188850, 1653061319378682688348354409274027724993404635187806461626063331496882417911387, 12865331742825053571532063632406645001352596250441781335061560652029557, 4156861177561915817901278656391899608541038862934517354617526608], [75804918466482188425558465606161101366879496038062609693709464925722239241132234157362216618759952, -1194806704625387201629323227538700270247748848113463082227894835070675121266200, -8786111651592061668812890242928939341742929901792435409294064015329292, 15068243155068850853091021181572295982449378307163241980751446402], [134295031026788766361141613878727649640110323647797836829211667242788135478458739719870680681557718, 6591054188340680948968999348929177405718334084815284815637629184772608243222755, 9884982418250130467940872517692998152333563289488661366267029536108909, 13186886474242819841176070595792887068861426125698514104412091496], [1470218678475574338311864888143959998077113261982806536519259245044021605915545516437796160305865882, 943046364058423396979480814345073920057914484050553821553633542741840025652810, 23476805929964622196273399940453133267109065990142976595601739458394390, -47691831834823168528067709362957987758820162311266806167070268940], [1348475960799767910592544169013709626324041379547401107290238918082704366386560706362820681389908764, 16854490614786734504905495383028975886903789759334217176849944369936989773989045, -7277372222603792896347668635924403439325236733640360196768304327176092, 27893258435273803620497359445135837943828909089696868956454790202], [-6672871543927564568553008747321677321617373601718833801001477831702612612170846629496636249130542106, 82547233577655704052695474852690733349686307854210327496061472965146792878803991, -196478601105071459674305983164503222648780873708769476724761865971958023, -18808588818198427000548995881949424959163029286508092753719702512], [-958497975541911841642539175376750761948014210373270709488342630475601871773049959526912400606802892, 1102402563162815368054500533135587893869425674297224843461195338264408093371725055, -782078858955274258899738099492278770720362825298819149950462276996150060, 2722271510439461079705309734360648499674225799805473194304948521810], [35255995238569072180070916446638300316431126416245312601181399743925677603958661788781978573433727032, -1596169127405105348770141417083135948938169626244179676303700259199817993527214856, 1654159474160532500613242997930037501613910704343098231178246194737802570, 2840779220228849883618405140822167676997292624596647409264466572905], [-24464663237832740708154736929250812578930728034663451735459940267978296259471792153179804253670182726, -2191132861759452116255302817197281169005317479546599621686945843598093479649262012, -394864325855268022271223594529453505298454461058317051328202398718752388, -381188189134492443051151781110760206000007971080231231242956792872], [12652477444711794723101338596686637545162547061446513668631862863226103519779556017756711457598573438, -2241223961203014883206958815891651635225848863031792661137414951280445888970720917, 5763908770212523837842871466305467810233990416598710795095100963392374373, 10534251984280782357283980953477335635553488830580470126836251293312], [-197514812940310922216916248252644703283243037176312190531124108715677586798546385301767018189489213108, -54837066237925384656173790581959487043334387846428498252182075740425905084735566839, -12688018534705240564838455818844786864711608086044886579679389153755709052, -37953321323546295061652652500166348542459825160868448623790810200438], [310890844074283703762209103749085122274725443032345334193318588625741928970397853196083517142142163538, 59908615295882983830827393540573089716978759516653733719667356836530031079044713384, 18478257823024088933864046684138267596119813004686849076628746657753625048, 111270388412186696834507134069266546945442119882796971743321695118512], [4447375795480386108745152202386163005641015701949750369394057902848303688582904366904924260515000148828, -2582018672498350096907374921418473217909995651046715298190559010336261051818287247, 251208573223967792582631479654199825054000215305525750067971796980084876344, -66414455413683821561234997151546041541267187600439164382108973378164], [-2022983736592615221368704628088977709320094594405989207996600655888068246147744431966705187466690509410, 61629084202007579488536572025276010732723574890846629913571224531164416389953060627, 7838957403602008289098581348342973890163181487874307448155882860080922173, -13960855936097557635819520812926445710158772288699389960110374066288], [-5582440189771603816083499894664256073053555834741823770811209564589790936085387783311739483507287247006, 89441749296307664803219823400764368013434311920586766001882172522308088193030443080, -55707497724594957360124108531861822769003949725623087936085491385279825096, -209373853739078491284018241035677785861973004417396194832083497776624], [-4303808798501740152817289883259028573623861924323198834987168129002936613904845798224129484352996519320, 1090225644844806640093913105789282350740503893636680400614067688569685014416210003200, 140000860246064229491408619535647659117161329809413797411638424014514428182, -533615265392906902816760520672186714277439279715829492911921617397817], [15735281866432585611825350385239762536407441602667277037829440972171352290966742254585267028484632169328, 2339996756778630132009571207744393702034365593375415954401143211045648076563783323160, -1115319014438385519564111005535581772100255608617830273896210038693705252244, -662404735424917238799344768396887518890292330121259733840941568701586], [10086799843099465256645957522275515334436714246769526340491366949394781049373254801590490562438323313974, -4830688653947101259023248064688408284070243371581219893142660560950055378681395356469, 1213785264378147658259686788047962256959430676327682000784479376889789032197, -1760688481129925912525066770205620975867371875974688147330735817676232], [-57511345478923253317141213653177182097907212009517385484453607689425414367314722740871448210540012320900, 4120275445706574304842087310350219509893031294417764649759445243648723967106340308729, -1021767606460566560841762354857693053004117112562905847218218046647739237080, 11120570628220885893900709348177336855418104623381948296476079414967780], [182603041188872925473902116358820146267117768468051987872370824625660590626473703597866048082492059177344, 7706071164131804658440121095851411650958151498977638441188285675984829905119871121024, 356878899057372232468956901709503628678714960186620573241507247386348918304, -59323776961046747666616356089345082189102740638579853184116885141424], [55340376873646200188789250827633790244159471955797843529281218917366782004672958425509565053032176975430, 23729463472607712729678696597170085106349132450141929913817398376192465816191076359619, -27494035936404293441979771694351461211301738407928942896635716485158266525043, 4248122645981408735233687718928355799277514067184676843800936957764408], [-283561236116756404693928291142127114008582295392654338174762274828767456276725031148468096048000888342322, -20537353063103217519299353086132549575191851000821701210392253405636724097704936468189, 9572220389703305754759660335779335300417202535788368155089041351739300140845, -81644960155474677031339032175914999285308382364628188526377297233389120], [68721649385438746504470376083591147308683836560949096272391844313568316791006831554413149871192346699922, -38361054532645811048211290862150611836896076577696021566893410491601272374533679489014, 25750973108067088920932307039389439241320606777612336627921786010476560072534, 183074886284697755256096223117544075470153508390750195072381890678568996], [-1663917364381996161954165741606955411234430733725757869919369195596273466057876794006748661626286945956070, -21899614991275035624448552465442144737517892452018272421245073330610118929905972306924, 161673768853284502844666380791726158338263878123025320694799069996854667105964, 217354524896190347079295897103986705477933687278560624529206579426708216], [5460524156691703055831102818618818236259903014256474769130428927374469066579235533209612719280021662481060, 147059373225735508430079018128479980156317664817469301151121939832020538452665348354291, -293072734287624569521394962147419204791148560187308307411340100112150655274044, -599544208554252020730174185271359117450099400885343658552026247060688086], [-17563961197954911470319518943211522760226410886245137127642381540283596995147322250968875022430484042593178, -324091558834772599923754284030503185968712307633073001987514506175066046495788984291745, 268993087339037608595867706128071687154731742381376700757341323151657674377265, 322750884662811532719574250907224385789316341075240168801138935428015360], [30867107643633701915564258274908067463997789320968219512756771687383447423467925986126167355544615349261232, 62600516880947319716787992528798683517985703518801900449562030370078462595216817728224, -1118376521175123405166719510790124556749354663695145703057572762506440780547372, 931557642034488073413167200931908011382797698800082748554575705725552882], [21882929140086141163286356958233070181163579583317385045334794655290714983485811342854395957162584135676594, -126662719472836472481380689796196154196322682697971132536001351144496999670627984056502, -3017445087908799051859485181957896209833853363810773085659974861879595909596138, 606167718049434585622180939242848731332200668959190625373415586148096228], [3670922117754792917849370935487979965689536884370630550300763947606569474653489252714275312866207615768760, 1282608802739354381187323483033556439912329945096132443035309779161080477612052881863896, -2225831623261200642125467193210018007931318328816360366293125775455506993309366, -2615142850468791046119875624638072000042405767385229756623613818756144279], [-3371858344569831192040756286049125356458694547175682659182261022810364806797879458156872008824224090830916, 2768954931739812150379007504677297276373719024058205850071825512254301248356945666481301, -3710487495867096673432946094913954385942338858909830338250012408328500000567524, 2148574268659813741337651912885545141287416755774466684063487307894921094], [-15545925132783050617362915990454384703231071324018240636850557996683887470205959136036757541247481325692990, -5821264973589263973371298588339206410916312701569600019645617490320493947014467596687502, 7186770327794772929254955878469684518557602126093217973885613415012062324924782, 383527579508404706570081518305081780365274289281662067203456517368544308], [-388816019841499508423144700012004626303136125686409074957285366072249639200566389432537318247385999711842742, 12999197927671112787483375434602643467171502230958178784410185560680841920009791630683796, -14220624433613506854042654255220542484569035194785734819479689451790675926746068, 17127966257413281223532439899421131459481122224574224333815230427940556408], [-322100753114913602132540600437806163604215054588476845047771116796868983766058338284272710341452231982660338, 20429845610580196048631653948620630705923355336073723770604264790926030954623587683232619, 7931031699553153210988149530451964116133406275734678021880557930307160760993893, -398683079635555826493961142518942608065857937354159725904327169034998608], [128746265419391347586756741638195932765863702798192903087513122439592521201048819902755229255115864194813904, 5196518542919788718592353362366669307663703098891425322382738430879290232028798879846288, 11842108203756191344621176375288374012544676699875264830490095268793732330343260, -11294309106732118411907753496028709728577285384457954753483549870630502010], [836376532008374517242964985535579249070818223476712455150397134932126290644722702450651804194117826887295188, 1723472974008745293035627685515838378907884785759548552261529663761398683336070170612303, 13312049220478315174448264143896060079292581038825507515955199431782692190229148, -28488254896720889117200507392113404128710345264170239985433722444583818938], [-1053893820244706055750967651460028357690850383628286457171463195207012268882614276739356060653573916613298720, -83768448445614263498892073694616599796879223441936970920145340674474474733427055462068040, 13346157488089259565072726800107575168859664665862285561349300221513533528197200, 150640746071847918346507477701751573394132000658708980213785497509982891400], [613835957164724024647641526870226317879302924006719049771328007001716613984790505342972379742704919749423848, 38906666212841531447495504370043052879212722693834229853218344555308800891516669695056984, 158392945935349693306705012116072878864755397818435117473207555452610786206440414, -265672812904948999456559960311142498287306773932790600964992347438694640709], [-6848671901077171320757220789717099570178687065900387698993171001999825934087052361624313215043312180749152788, -18715594941855031637230309267244098184507180826228310105245535885061599199165584423715451, -311884871512280324524263135654506851352767466515085273869668125342104907292567360, -10140585458402336256966689714545432167294284807791793109522173233073143840], [5778854756438404171733570144937890438814263903717070484682253073190821854694974046857397265551146844578712820, -597187036499471655568567161666744013091748552484609690296259725131866853685034871910826749, -759221352077043209004009079448408536195639127178565168068247181256961306648736256, 465997545649751662391249140783411961464997568790606323691767459900334955136], [-9659062187542839860338208678570657702355583198620897545177809858454855532145441158117529278801639332299587336, -502415153524118199372977948822354766623097683918664377369293261297535999908520152293487168, 353255416374493612852548829572958131043090777005768704047736255361201159173264530, 226146787295640140503502825526906921665469194375392244602146724841029794845], [-9826869099402099175561079086178890876981094202643340788257772670943674830654690776077410157824738895234235330, 1092308386681327478272546430455900048096246151342668880904722660829312691573177366343689735, 1236530578684531219821413073616681590322849894791555871273136526540574660298289161, -775733408890873875956768912725646358270288413875881276435630716795670616], [-41404115212080788614413477861692592937631903073454170997179503106704247723041631541781199956517712914527817078, -831440195523707429446189282318776440300294301693959257532819297702586767551977388284921852, -71073480427268177523876994595658526488137317567310750485494401136904494218546244, -2982584471499657075360011476532551710097486797427020140560947215239763913736], [15245632265979422962452055921151711385482636820508873104847093596810638607609407211565590021401073661404457484, -1373083931889899936639241098032838172496541613998740132858360462847265890754795494043619031, 2344952274900352559121135970520959049195918465188575594101885600541969439705942964, -4558243194258592607195268218705893055504112567211821029626534805615666619134], [112123510612207412839446933522351374854435316600131796515207357567796609773404262214894390253656960413470719582, 750564114127724940011866358690707663586888592189985942500211198060121204127185826848266607, 5810111627480868480805170531559993393100408533538098490721910834619739154911055393, 5818916578720729035220583089069841649806565288389206683803135136960571635192], [5551581303537816246430599116678384980142574924226087275656636836556642492795025587539647390168792355607497508, -4807397210179874327943401740846115988477082529249340865587426079620344292027093292288005453, -18966642380510496069896179827067829928993528754677546921576874764526672242092394780, 16330211560640020068316494356114886685391888351386229217503435674276475694330], [197269584549069052549378523500828527222756972045705677525020388610416778681076878803525559371941510786088720238, -32088588052034243510894580171336215163178392410475292361015312548182276938445871409442820009, 2899678172675189215370903748016161371071365081934743631526348613885697801283148985, -79851800505058053240363220807702115787106400923026847288782495691258281728360], [709794380884172342857141329608970959781064014847673523317595371643087920045296497893791687261564785163055574324, 6044727626412845645685391171661006639736802221557230290255971379818316940003284372567063583, -6401962079784976325426137033944487852246662645545997997019274037438648761688733068, 21082284947734608955490941115304310224889534036003329822313742808810723388258], [2140906697967998058742607797255788704263403083713140647216747995824179665236263792343116360283021423036046983610, -36457040334759258150571607775439818350286169049498039537148714121307260357545698476908564732, 68346757048323901163903721968532646098512380641567454675019827557330040486791826620, 121373931946557836589844559616180611290907944981232057902585073615678931820280], [-1040980319414511815611351337272041191340415465883948925125654334086063917631678630530242321881650651709274277828, 89144074144553234635991881203369472362192980382436815204020818729877532340245711547091384549, -39118436427620820745453772832902162546409777118169726833474729838725501095215923412, -27208733819637717427069658931265487541518209240037424513419604558816946839378], [2599244182808158449646860266515636067965246361809985853307509562330640679477003393377300863681826508152735555138, -254000314612170051623291316502412337594026511284484467406826449456862089496593183906466093816, -44762985284211916370816120662139158996071711349774465123772813559622174617523006856, 151719914669036055032917632474386701158280223299029618447471681741511939167536], [-7859107052423648739612995080297298117720997906266163704681106844225661423765796828291401125085416478394413997492, -139708750893829670914211495043097448585505272777748236672885673251047963772807723957189612559, -746408607607109095925024738407708633515586374061281926213281481731631227057851917796, 208910601950746056078095480145487494614281091799714824451917329931307598478726], [-1650617119422948054035316254062716672405390211632703826549307686285808760702250957577808721852005217498204654766, 49883020873025431113169947601494366973290019289369435644890988852807395426331619951033443152, -364590025746968270874255716345110268734379031528169797925771543004939617113587525712, 519051060248472689998695948757735238886483921954811794399476136100805224683872], [1032536232625598098541543601480199959736275532787201711412282905251471178903439220191315052583851711608148981080, 227522438523849389597732126666236514083386218067842217451761378631675659494726117074459002568, 569667109342020529309847350083962223969937450304768173789377029380592714469520851314, -186805129665977505092869255772025837171154167736896842132966708310048143529459], [-6160220536625121645493014819179052639297043976262653689774896776062552557948888836891823997739764427713903193638, 559188878658312397868213350860065158467093726787561667594136838938005580706724681667992272402, 92392465973372206678269267172696243535688571487315502605285133549902937626205011150, -329591408958703200508842648084012169366471428158087929470582483374584265733500], [-7800686831606219452571546484114239074381584190740363697753026207672723248558394007087828134703938183337992022432, -719388274615188822330198073193684630156581743028979836919312542451282206483391192296819339504, -731140379302267732365970431196101033584369039657988405461288454670009455808775422952, 1106845499148690684272333289545451471038806166474069866392574368050444010121212], [28473741685662528467437703971232554463147843738426131920144345455494663932467238062860519769674644035550067620134, 1222908709840033353016741152693435021163486482568237465347261814532451755175212387706695185087, 874325380709927292709058823642984682270601227699012735185977451946280696265013308881, 3206901243966876358581643627845192699577213392028227092696339152960317323035264], [23399994448070065538559252740620510931743482140504029034185723401101916199305276216706409973986938963636549738218, -428676507878571135578021178460662559344399696215224803263494058566831285829098907073480291206, 573732069342120050068678111372761958657630711685503992166193682415444568805045397478, 1525651244458010922779389811932338198730756892029794086050860148004863448214932], [69067115032193089786073541407067842537228079420755693807378415183509580249461696404789367946837031273780356327020, 1495790401942391971122799616544874554165402587080875496190811087258856811315740048622562001145, -2975920214859650887330609035137462663973206784987051205697226729903848656387838652020, -5551891545902164675079809227588850757072840735772052069979569309260408214888930], [-120714568519280063827230858280322684620247016092757307481906593686583155147244313400216272563073485919264549555848, 5014493658432982273870718874674833607830827761601447259097310557060329120248812945199630645984, 991224479216798033722443450353440782218972392699051380858239293821792290566620025170, 7933957294311653752051411374859190711708402064784247005811915277721276353803005], [184564100099670814213635491548199787989909232473656465367506740463929409435460654023047695108581107346300499059842, -22171654163942130991025981941731503832157369863247615645189130737479604620811634897425648384126, -5065592625229886057531055044882556063641734774455597215991019271194943068136173817762, -6219708137314495799713323322618564933008692177255930033597716875940798370028], [110600914221510408001179979880384352461428493715097324502821242796961743357200293710359224546062710587507377072004, 3709364609393653840649236008587061572437450171665841550394075635865298729637995218901590237147, -3594054144751631745065274368059236147576883878102962258565941556358702912214996324700, 11550352362543011996273385438561651365935120231154002593824780104244447651708250], [-90653695924543522850244254106249471319695654967238574980337745544613220026955955168742358030563958091753073672312, -3128009505323637211229104537759483395030705455123224042963136917719401188385017737727150255280, -13945937634363639762561983786988797994169209410062450021797751648893879942652022874946, 26415599387074876455710719921373863835299606682250115528271230558836876309047851], [619727594557090894675823244698799868477179992988364047372275329984705329457794972590821998116337332386291789074894, 10338265963865194654729869585429044152107309062041996979122156052988683779161741756448547276171, -2063343050581302989535993495355334241708343215751550281004704406498974737604972172219, 36621634911043305610353144542257283195676497335536541766551951620688153537143664], [-100462082511706922899642371820147779268152541142442778114892889928860714345419368924723630788226458417817996734060, 16692589806107521546761846453321228776982433822608764551556355082625357513576756519363296714603, 30991002799892757315120483058174682458928818040183232613782013461282687113983216174064, 7081360630499965874917221369305334158646172937793940820347153774600931375837016], [-370212192142378030150503703526590373048884903880602858165040842894073897195566688889369466790179983272766565807018, -21061024781524166191824323353628201330298445251850774687850552099515317494148590887311618815785, 31914045555222836418267869340482828839730594310799099189584389519877605308823975641657, 74186704594401604454709361683299338885273895834509576307784605406347975631619808], [527776681322183815871129373865073434919345853407412593132125366816628743621371543449042214304443055750398402125474, 199240113433092541024380637735649963468919512104192337576234734767290944073515183796308723221266, -88986725350996874056809523769607164566747310289913367168862110804087188477791666828338, 78446287846587544228965541170331257054754691051166323021336908622831739143770228], [1156512760610110648973695727131467147469521073468906151908006823125940824322565608445546990638428695712713787658598, 61725127001313271071638790714234528516877493560863730984237473886460665989147894466944448064323, 99078652354563193523801916853337442009812327021967434336007119940860274012130300284173, -193440026804413942123507493988130471930735348925574988868559447118307098188659688], [-3048254870352717711628904042158770606648766225869886303127882842647215817747890167306398457822238725865057785911636, -73519328304767675476941378772756220157502820235162959797730653043180570706213465466670808793963, 66426802317232770254640187321701399150911929142802487119611856762237170789182602216832, 242685076967337216354389288016218336950020416385857303365105835828519220374441408], [5336956776716062766474251323365063634923455940558014277609943977596572147986191836955264394415793513546612042003892, 72877565402400575974521695392256788310020568903361707979155579847004908862183157859334957188747, 327766898860481846118247743581722032706702409000678025396570718122296947089381095357064, -151547675100825100295192161234715705792508940750843616405681584846796206245523884], [4040285514782605516338676273687362690025041870297473662911128146250868422977591651508843403023668166004254220740862, -457416356282320385015109335381961959910691741397349084948053790676115282572687049520745578983649, -415999023893850214704923704022496682467091953438663418899335613436095289785100565768847, 319511680907647289371553039624561957697057688554546870705731730391087262466603832], [21493269838463494438546225917038974978327334489927937467176932220119786438578513527879415091392959146097763952980870, -860725638561927092170244389549225788614951539565179831038978225643160778867701348486535418240029, -82638334605662829974750028555473394411623780564515821860386349911102571510393143369107, -570133070609240547321999549427925468214973526511686290098258822541590661411059208], [-40795138718651411046238143052764179729911119849222426331321679667713419438321135283200989158274637944313303843237680, 439378562500979847104331244291512533279506695814629461206103670836740782649798056723753751945504, -1344068269525683144292846201388204062919357558989782953922442013377036915236974623285492, -206031607677894126089373471498356062702481457936116736637155049191039952995237698], [16360467841512399759669526431392286921749632838741528580543172228685289641299054899126566888579309588831563805418968, -2449074945862324929169320995715399019299022040873878672642269615084331456205325130774197218781720, -70583114882780250161626147882859526815029578111257757356205009445360152005196055847886, 2555987565225456343148401722707897366615156371000022514084977803628337494177973741], [72066118002975738067015599988506597068958693454475232973422245238765985243716304647296771576695127339752257748346654, -2149656289277392953119837113940827951973109656068989885507183067133321519705510683261585441223557, -2026990446405239221481888350179617743454273422087325669069189126658800744837887045227947, 643655531999581805600945935322747685684740693332757969545870157652184487573076032], [-51716399084514165936898917028262530385266056943725112625180542315980160119719442133736454889689950107932194086474780, -694905182349969856102795564558272365436467488953854235602169408583887513080367120340792630607641, -2112168741963585536054862661951248024869842506531079379867969567949907589281751626787744, -6732593621442817022956873926673770679999973243450523461430821234635606080363947536], [-235490480031342720544696652068407028448727009135623781526716334804424006921684456446457311601079309367797422194732056, 4711441449693071939969506042481280728534860118301942074572713154240204199003501623080643249105688, 1927681865377335476913833162069977505088901203464604627763701171829964525553738174229726, -1687361101819167961402485822059909947500551631829344371383161024519200515922557381], [31171098165176989330996624884246082917230541692074789448539292945413739496433778729832178709225943330619541454728432, -6420872067244618314380545114342753550394634841273816528318930955010324264521979841252163560085248, 1327704735031873938023052044445862610864147340440939402728252272306562953580267215333092, -12460604973315125571670079595791232056959252424426276985525423466495719281582886502], [329458676201422368560150504509503384165431545013063267321724043890397407000259602106985986550458872753731099829582518, 3832400921201388914152004508809768000223351797248566455271452174493875552425598667147445816837759, 5264942881946712821954281820177029550076391800194316643408560991753826153637233734574609, 4759335059814458081226646029260471040473012803394168074888054084730034533584128496], [-90226480487544107460709979439831719880944255447390231315973627367571842673992863582041038518740702644409504717119878, -6900347302598467637631202712616241695822980725180170724618257996229885240682849831040894948449020, -2631814681118596903491277641827690193328361557155754977452340553305631343683644523766084, -11323604532232365578263043842379585570044400107118450273359458020190740872091609896], [1026361975073464255021561233713296375343005626056806656863230719829557974438562592493428512767217442818281070138678530, 475890176017676050114425288402288520830945394511169780826221447828602661185798988328997607100178, 1470688315757358547042933578596156006981595982017692110015781647787778246145889881178062, 16143459185902989977453223667262136378967546596569301765473794325635227613717402228], [593153234670348756406950370163113332507647195388742583536857685057036974614251992686294605997866255407720371907807174, 20887939205057542404789368284754756543463825500702781871733074159639458605573804007934855926660787, -50810924800695731330177363225465519008610815822144013214099655618682456628969074552657251, -19939392053443292440236053997002571041836825363057386586043393591315399243054941544], [1195815385738784947073660059593204546713012116816622494398052429369953433994492222733814522596260920195004073047659028, 63642373783617889165401617759059541865283193235797545246647723069649446190065433722910715744795171, -64182218674782089570620587201165558472397080737765150907045050612115982883734639831841704, -66499784286848483892036533271617373720901213503245332710888141299940732388162666276], [-649418456837287813176923694938809925333550034148569171747148692172455975870082359109331450593009209153204740987156642, -22393250181202667846630967895690864133385293437392132394500557345484872715874355154998386626359033, 95711826316717514133089181119613100097308294847304489815022413580628627299325593217531145, -65138462307007406780486517414071447227042645106593120926578047168149552220583696120], [1740434785459235652867452666735419466612582209479532057912167966232307103703742004615112787250497493014741005140409770, -71236623912583664841233012375801671737010292726480836785863069706459684857258331820799208662687356, -91612172970470319920170630156928250389419625290887282860745851586871753303908138554164676, 33679540930215204328467206875351294606533800080833596057280459134080696119342509656], [5926138711831238569542232009548555584637847243081381571606663560896912165023256627127645367994449327867502421820022572, -12233227129928317774590572963010631101708987861085628483232448621036119979611481725853212699637191, 52554570918189505286190173303281139288587557567701158382366728202499956958617191059906204, 58685085759575028583078473046534684782775235565495546518316545527526468619118365126], [-4646776370389354349686069244687076823796292825607328121426851702522607083386667832505043008036448899413217797658658058, 8308270881829535351629428345618559994605105939996876043025459762264451229123849900774474937726411, 227774230369599266213378424198804064516881861235280479657453843143187694372684773876616709, -29660836149133534318086603317740288785411712644835123056789445468058453455975364104], [10719498768315562430052721167518991227028454492237752635701453000614824748043842573258536364135999964177476564412328504, -72018333792379443652896330201411048509121135236610314852895545315433623946645914637958790289355368, -162991665502763161197644869542329065710580379558811140663245719480826831822799963740550358, -133770586577899625498045969809746331559410437295041749693181069880621258373636433127], [-6303517942297021245955253789222328335615935510075107723740028166159894691712603900448465196985041298246058168489719492, -101135845986425353678989676935037681027051697501272846182910214139183056556822377475894007073068803, 209682059445245145321587699503945555905620838897450713345478750518498373226997311284961812, -213848054956308590547212131446806305786371785033884676653697659224794551419088078222], [-1502722919748253399970603653535569973374944666222186675240035941366561659342357480058460272778437188033177177240921730, 218680395882100501668092563750119824645871915507860123855102138232437506119206287275861242657737703, -433281023764038713745237417584090326238607380924573344353515382140126745999078031138702295, 219896310886025414751963319372143645245116076145931516907185874618143938136686622120], [-4072886874057526309722972003832248438576714259801042346105955732624900626904864042514502555467963048138451148398364600, -184817699894140080660931631975971497625721211036008512047617561899530522078581695753961620573800632, 959625512192535313575442874091761491712283238874419286322675956349219183509927226866363222, -385720994573270490679312705295142730371524970011664382064094767814315327038483204057], [30549260630792948751317314745758212904772810702850080379841929563243022455229273960470223694517755192102863696259716374, 830462763306950055713532702056221791631204947965730301264766754418089763906190679038839950080763427, 1429406655525465885373440715601662855842876479995124497259036738628846959525034117873115181, 1960854384402774007763730135113043546171212678609807524179792390551089248505133433064], [-55838392359907230072255171147679518678135881751231075256368863429661696863294672470700850731419365824582412541511152422, 508034151412061143565808840145619303999230101188236973076100194635236220665081016194062761077300132, 319165002004167632281564134019987358126285831905881840706328848743341524219974054390896156, -1853949202439511650410834059235819638152771504698981172815052630458331676688642849736], [53832014648845799346324421467923602005022480445804544596606028836044532121516547553612863229800374447095569223970194780, 2153142499084548581129519191124317445961906018241161543306427614445860971563676567053900286579614625, -44793937365332884150041134373562280787611624649120508091915200305243230063942160033020408, 1653086903048048779875425896675250879255281979117076873927531695431356480675483996948], [11328273178885582617674578773332162591357453052046740838820259857930959800976070662119712262752873745029007590242985824, 1194493527047330418298942230425022923920362407311875810049146036395463838840174508447638803316648968, 19723375574002861166131166625555579132106164780294268116959651629734563285087203835703072, -531124357611008385249581226822183438462064991922317960021821010515143864822720222832], [-42573813089214084171385662701001684049328147472014314547147854012226740548320028952283184615559693782683805716586704722, 4030491286564306811407899755666535292673259036629386552636830353537108611670447880296802574443312907, 6453244073087054190799610458048022404210710623762504068375885480594342306520379571842796229, -2794013750509791488755451109073980898196884734358458147186682329819455097458416994224], [-185540937206003138898405363566372794925639537636555558630340507388741922413561065265588118258594134653018597068223723918, -829134431504463734799489276445627884696121040600343022276475917157974450321577110681252922397767832, 1302538198134678264559156532280573263976905636660068433087829828653408458411367988027382296, 7050286258824888011754181562702976941968347070786730393909020641566206787292504424624], [-51852021529927852946415921765528498502554790877221736176369562505952828487253738166874947361232677344605484104801311116, -3811459895849053482276992022477749639317164620623264398456516467537490318391138015304892487724312665, 8864637349697713488854184390354116293795161337184342791776846016561002152686346597992062940, 5017386663437918023058661846996487231217405440679812767423510838081112332473790129510], [-67656641345101422959304975328219839284846059939353166685963251529145551146205087573553612322969509831391857118046264712, -2265902795948267885044193978010419666473506529756492903240766556631696712651375284751254816163935640, -10015446539143581251127716043004922851412418110057486431301453653186987278139987942554572470, 1887558236512258755404603965167297322819846519520785506230891509765313208089067751145], [287089583380309501775875815155879973165832636738574555544541618046616819412737844132427206990392775107657453397488722828, 7784266398311606920724005493271484924302674801176569317814710857037604494972546280724991313812328381, -10276492219712364828002684205464130874079986721912276513712515975179202342433803073052256736, 13731700395261396282814307502928462133021788549625394789287188836354092811095148673616], [382583016496396704112543287802960310948528134192014485291890855209934539915435073645583390520875393902673079593788762512, -3175787382555460948064844580572687710707388947308590728977034195345999372163989302360167795439359432, 14656807305952070820569783093655290735527522326382012504470526002644458325778328369006264196, -19925984399024350123770146315716770905082980982245257569293420578016902704704818827926], [-773636488462518906828940068024263980393495067891827805998788477396311622209109215967472200860145781205201867260864921960, -17313391876455621391216899298131078319580154249302447843347738262101861534943149081467544737029740144, 22385955406918439955927520573489790511560819265975498194367481674216727710470364155569332634, 19811137693631464584423981640975358637578438031851953224933227201320896991920978657521], [329973148280424013883776969020561030265350999588243829716784554639394188579227610142430537031235999239735234853729767330, 14644867640756169719998723935814826368357726390668945057442165321734053344355854042567364918442123762, -8793542680950252993290503559120311247077138505934916106622742024055719803173209802144878866, 33837931217047807947721362070385129831109145405301673537346647342927481304358217857396], [-183475176951616344575900977605879663837747110973750767988827697585126091259299480350630507641126391470810849677871739862, -13141766809449182255046108777926354779883992710839624178068653878689178568332134033103102179227157182, 71931562539185603351930808320737459058980957029686506886525268392869793065380972100988738206, -34946712928356148234468819139254066040697195612740692854074154819981909337372700182236], [-863075905716465049968143605939337501132859804699957562687433065411079487672995200997069189826327796669528103706442801938, 2612830122704614624243231040127095109786185544450100229428169845100770536398871459338684716251342483, -87873857589587970946543627573496571779028663607932951479296283694633344128850445805956619587, 104215931792525111354970813234866404629216206900658852787292779095007417290062042646272], [-538193769154265576983107392131170953667969959666003853301948814251770953065133633228415241410992148381536582845289759052, -25260520576754018304152779293104014371927196749461009057041388386426567223148370885616636282177721425, 88000084508830597002870804688208622303551407680333850144307305982841019575155347418873357060, -5057855138363062523805297174410331194714445014053839602552632466253332549638560928310], [1705173117403059319999718284051090957234437055483605986646163970263192695145175260901426673325434515482987345452503411514, -175229900513768063911921289774159742359304337963010715906103915481487283998188781137438066296641927692, 33353483948985356573210394042649764344804651806953547529699402692009082878194995971617187532, -4544340744398378740785956415098487978726154966302979345878540616241761621674973034792], [-3187925508090027045270690631821141505586843205017607580692182778537650142142711028498070743071474505760745347297650399032, 190777568264190098820998196500383397522022962109544150712697892855586755953305221817924638708940753416, 238079575283299677835322643755062561353840831018869210334375758143361220321778292677612920182, -175419568799576818499079422196456507683945129243795240393326391088281347279881712769417], [-3095982715135258251609099133350280835875045195981888958542843259975128793361487557068313320976593823305044005013141861428, -93771250426563388213255976432908904546685679716599247565949311427915477093795436762685143293374710051, -201350106130185162479376236994140189822096320763822197518587666041462830413133995072713786512, -380801065094142659080945916413650781248488962188832136321241686133925408855568512724328], [2493558942644441137440588803776151941960990093590359744082423518461867063634454319978766125317812915434495851565841592018, -293027022636857177387771494534430756289434080177348860816548711951559657347205686365827407562917604902, 255353946754215254598054874466902974381242887474496372020401318178889037376544660462684799110, 250078995951924379019409808204817009863024392108172896907500295175799791214270393671940], [-2145454129972019887258556132696576103844705257955863224915413246581015985568792605922232913097851710395649878870891714856, -44679149548377822642890199389329631579714924249664710442205584032286984165844567791800574365221836584, -178694807841205245508921330620730257857303516051826414871560064880863683502847162070783517822, -622654083331329041853602143017990104206813213972007746896630586249741068407076293175243], [686847913182449045975760618729369666114076430354672834085998959181931826995282406720162533846853914961608715992028186592, -479308788081566655632765870932948702537868951636574375622742880614302633972825694865143512512396222432, 284638434202260392870012102877738362125848454271454587282252392421639578717055230049765916456, -318753495669509223160023516626817811021245221279384379794816385780895105810818931251036], [-15051131888603739119334116020815208364060801073988352020165794451049035584547496899767486684388375283010753231405532133722, 123882622021242640109589236734934547406634832573345086691434147382395935830373799901602856668544210275, 101374200513481231293616980566507641231083111217032111663894050862545704809070977328591692013, 962538689823948353158374765529709613889825934501642194344368080785384031479262204653272], [-43311005342915590618836677949871715991170230983393491138187001799041977353933044192505961445802084216264275939208669939470, 185994402658503925124178202322705643580078570084863316494743754001018454047395985042154147092774222490, -36070160780732944531825343706194977697028996341516342037249584910496457656828979781104297018, -1014710189020217931223478563291514305114756469424765678906340178968200944534195996943292], [-10848741025424317801903187724342715665401751208082765420852473546139310150790691815983566510055822676451369179770765540426, 2328571050246588082256064017025201744253376923475031603612405836969799750959655807232494650542439612503, -354001849057268373183398909541119473393100696180562703112548080238011363099777620763633796423, 1809912471076058722009196295712638049663780694585944328645916888318961694148298139837888], [54045060622213971972411924522708671427232115471883875638249134363546934609048648534855947071237977584889371326689451897340, -560342657817372415561998906684687748740041933499310195680581463794043031929491256658573453875807918123, 837650190077777849771104461163772905044316737782211610899763705022670687335504863439384074956, -3539665692945712332721043200560240799743908980936139461157261737642668296714289193541186], [-2471873835130145187704234068932458861240638023148600286360832854932752730455098327697643820383089414825535268523566722498, -1002477842246199708687892325902168460300562381449181251756551735134187997302460494961058130643057178493, -2353666199130036304389698423219282513993858825398918388129923454129203595380625051392211774003, -538036746775105620791350256443338014963570041285703540445569433848373603345371018608432], [20656859655311779155408137487545300278445318210442803670402277054347901412605974866195515642028659191727445075686877933832, -1147161727328682253725334876005346448161575436699547487257520368380609023062048640593328799568236480352, 723980493717352395862014901934686364514459156994863511715420773438782651258005976345934829966, 5615896309032168244914658475860450620333657411187930970318303308829632293548494447363379], [41975363049099978265455089479677119693691802387878282233008744481966160229759155376687761334027859632239400329166797963914, 747212212161749659404026243078017356848445186925493490524327388820566365447295471581612767974945482026, 877281338367793858708084837711269588754047775874292150369849601221112939794016913267766588470, 2904060822898616397209889714284942351576274692187231649250824095398247717571993531692980], [69372900377875553083040205235295154778437805632333757981266990109889531108670777391428619611633489768125118408237488249360, 3104343460323821712521118177410434596623972906606905561521663901707292937230453945102324825554362558360, -6100385823903228914621927895531079354642371110917174200750241207324787549850968771986314327548, -3724252878776563455667194221372807519403987539005569057854781860129420992999664596306262], [81304830251137593074916039523288175129131746706938701448143780741279528615029559661730950299703619239135845731421198088090, -3481002672059676048119483890155487015651281052926198675827969708395857663175851402398606580916081678934, 4106553096922872578230270615336297772909923482790449034586656307291009001148108278929606609846, 9732090981238053000992589454842000411496569526689328176104575570968568520950090068380724], [26459840491077312317805074602559227366251366463429506527023512593670077339024477142539642969277096028827309829112675536412, -8409607170683494956146657491961833819891602960024397732853586871290188944744592657941788826615419694871, 1529954159589232849309597873670294106886595060043925985701354993925637439012795289689018955984, 4335310313724315246479005621937549000144026253146437741908462420592862844546065818677896], [-151943504481626395363217504220974967394460906025842935608106734329216721413911202572767979001479796878418577718873612225818, -4432232400685326681681326111898593840180255096509312304585017449555036440246299177764457499230740665045, -4788471875546774561477929700426523704017715175660874233960743123326007696503034668386512462683, -8601226061242414358662536174964679062475059271395325144025776184652956508274744500788152], [161468207689335756243535510436959125783352699596006137504579492870730791736477410511169032947876152856557272355670553627944, -4934517620865411462531795154908555726713490961155469730900319802091681348942082325127721680726466786440, 4928366701725633468096576328931564335942029873835148904051511196495138244148260840090744863918, 15488038127137585664768885830241061231736831989075530610104152561490697083417133021094467], [139054618394423899283487598615515511260665453156159768330105083715999818666095766688184944934549293966574226538927007555950, 8673027422879366755675690548333778646314241361740766529867597634957917553301586459606854258243309925407, 15949729456413542065181285839858268717004370039762939855998183378051015778094367595055797648497, 10061630481189588740986476449857312361003874878354573293492380212845891303930552999418568], [642012442448232145650275125731208587550896779597043146427434342547334089997842823649962894004058803721099894924433748491328, 15530248996470001089274482691219946564701481596284490039631878668801606154735158227573731225574416846368, -32593418040215576214628174964825529118996914945663604323702744675246025969453730682897184920240, -18470277669841382738159764420451560666881686580273278040419346512715154554217405196911160], [545063013200928154017849631736254402729694732851378147974364782668183767444652948787869180611950952683017377440617570347332, 7423036698806491399867650993947024713090214959262367096890046247087304467820948059271705080089845400751, 7922377116986864199225604362470241826818456605131710790706854259533236309542826209113389655616, -4151136957927857980560176062274264888212678946044103586458190117912937853781188498956896], [505633715771558157021766092933838799522049451907180863198536589407910337900339073305233420985693942116688085861427844380934, -4757541424269632169926905809504673578190181713079978557958736872503406077238122740673974326328292281121, 33679768783746352190576232219370208773219073288555997541586605515626308561473110599047627854257, 18941315184738050940008374305469753729675326785689985933569385489953413484034382097186208], [-750780164104374764321672606642417597532891957018374966999710194814290324242058461686106655939761952752973549939741100869942, 21759736722368828807730646634646092173556327088382726988974293914161450491222561999220964675483031195242, 48837304343465816988257882646851550064287094468610674958520848891027484600560314571201979672310, -36340081148009243958075851898192724498171433293871324106342546202498084188545614793496460], [-440550567085309843190100870412335941347989571128148218519694730452925574659421941863720079283802835224576002193423239957936, -16278249858706439183520579078911485404783178357859144327358015582337902780962565564490620557138506012632, -25129971891927873045084857189249158966593537616798931667411663189756226674865554890010694455708, 91746930453671254669346805539522191432247037046654898795850576471911327992011376448348698], [-380034570816269487436602561401134250203136364547849293229522393423768271681362467779239323090950004514599565567567052242410, -35435297838467789579407282042473356926217269795254237927044125633337227820076147253091859258977243944753, 14972453195592428077342156978812447826188560116683624393240454776712632436126987432321965126337, -85690341500918691498884803854788908451488175561230145340681462735537055598556992400701072], [933178937735236730563191621665413275881686128774441686793986808302858271049761193731860096064860890253755255400310734269598, 80873976519683790535469278812531247375728531006325341196721417976403458353801308755011582946220747038391, 37999472834709774848141171212903073394687313006261709144706611831121577427612730671954254550105, 60041733946143485360712881038897391866299582678931115117475980484585447155128585155338920], [4043846231602088642140330957951750421743036404324698210877293519908235493809715726596493776478019938244776444745785252646244, 18603064089833781690402976763388835593137186912273690186188699068519320488301016937162757133616190668639, -77564961671383713852602881952332976626314437366293778786163613279622265835360310845321468077880, -56259313265447111977874089223445957137906162698088193946040273810934928070666523188411020], [1492874503826594681512883178110674440600388675354408054597389727061978681460537275998352662037255424167968085099602540622570, -74104176051320574646172317930560280637743505805006136628151689960507346145637657114590902367003888611212, -79477073794675801081076575996997514639967134755067606247897685071874707061630479459455884542900, 95158476013281251548587938632256760776827794006755774235282821494375276474543297477702200], [-1182170450015845282226165985585096745412465125563540227205937027096727651568168873204487973196332992308074148069455700478848, 120973730266093975982639221337744598743936954370239772497300772503908539097359624175042781300003488694048, 128320680678436132611402002683772343156789384117657074175998284582016186924748318560822255690176, -38249136848987165405672357212276468793800587117163420471596239076555598888295053949802656], [451377477136637829892207599841611459545481129174495873440907366786694697530023792130944387690576728375964667453040789484674, 201754046115891209216302639807957991494175907849913846668884762195703499149464550466058142958689185976616, 168443592622238447993814772823525163298708931851661244822188038366365608842253848630475255950424, -235638648728468429003217294096043884643182645975509136357978525721606270666503138393559344], [-1455725571364576183860871871352529218793018190584594133775510827422317405454247527860137594140523176152494534349357722479476, -496003121862046334442959396527360222456559243059278549460788568704417479807393392751789285421168590902331, -95848419216133133580820528451425861438346949959642519644958315577539607371198548759388933084776, -11629042546876804515641612636360364322610158657631801896464640458341067166933548040071044], [-6154829123212569928393722909826300955272539169674279652392581944294640792286419649870508285196444753060681745366568882324588, -57053339847352997136768521219243033794132591293464586461624829180106885530607131660789251654240288517649, -14086249637382774795074545786481569263126646108524039793104184513275239525437356712082692828724, 105946325680909836603404909501137505469024413320823672291203040693267622651819841484818494], [24728262549905750896947471686719020597209584544633020008162474870201968090453212256116813315701054837300214752043234644649182, -432680833536866873843025777956303010342103331503012358975517018505444188597839715111412875012957122776773, 432798038642205239120542147796769319522851776726655911281518400163303553016156867737503841122709, -797615055253824106198449722967619520582154140638040063542099908165906937229137434381939904], [-4985977426428044185926469960932499143854774454591370325487175797336158828260318276255945722563067891623209395880863133780572, -885162359376543389709752265786901496556119337878279410566769654354977879897024267767848966818222164945137, -330223379475048661614388253030336517725479446585217573193753651724450179691833171981493576049400, -369331658981779885168154824392706471006601700129257812606111888068889878407200584884369900], [19736289513923224813580279498560827815240114738764207821783839088353231151549110532990755066631423050229284270754820377261354, -563276448622803459296944093630252987088114523923775169314179734096040328276940171226475615867284835445126, -1507343422931622696188378477653773311827612517950438401391678354841271165782832781458066354270746, 706053827685967801390770176667529416125967850858740713255282567752428168000372837557800276], [29604684801659540458583802824121406391485074125963523600746357038564554086970596883568479688082073190977610185281988852822962, 890249917708064859170147516140406734871861696210972682849018424035003026533387502527670132374842141134096, 1022279686020605332978205339435614147465117589656609908934207733357040308613718807294575529439728, -1284246115332758956654214598162350660875058623542542679575788807805866223768144270450910368], [-3843431529216167138874899222661539391857948888480868075497650221640421737799464609811971498759936783699229685463140892269826, -571011672470138927113193922858993077962070427412209970014701656221261281958603554233296340716059253584041, 2521083164271941002188995432703132199355096609226062046768632043625371804303498036540368584757689, -1297565231048541342435936585477712592303052143864294888496522456371467020091132972769694584], [-64731251981350190515300435876136040419553499621129481204598919855840662501653072592755449012475393441892557716191421672349502, -1535430333889839595733313422712376506586185845535163638152117903235682904056175871191801885781488997991392, 1509146042403092117625577891583536923233406485549033556276055028188717439513729062157257851716064, 3507318719773057118602419478271501018888239780498515709969104943064967086236628587531985216], [8388787841320737504992807768106700060675360530371762304969296262283060301583085655471725231545392515171048477021095333132744, 4416140861191394754637234791055044623469949607211035594397654752954395282950602844223953196556247236848480, -1607447551862429755282245292256532763603279845018290521402275677326366874950902007322577925136098, -2710685596657004670658709893104977253808449823599954724332739330286454434664771740213518437], [85859655757564614985200245673563275834496898713181814431105395265286581246965773072230683328096902425980660862549997534381070, -744629541280123773205795724072230010753575738712133634152306267003222443837665553229748404944135052518393, 3003909756946402494693651996324841579272211977862801482455671081021617359733992785527006200528393, -85864061844323069622277938079639468769140412742149332511225773475764184488959682768514408], [-92575871514198769224260012436344983446870889296790759668433326063934590688911501336895617252717357418411802460917144112590128, -1477405767237468331603151729055475892308980700891111524577671491842968218758464737930636783662424568448512, -5948440736375878418992264417337800671536777739874720840324262967142107621546424336687349737672020, 1478564188259955420413983412304308611770904226727829436177834023971190669347012078610808270], [13424969127873974341529277821373252150441221855081058590660851429628094675638789029484328509738598511068045298090867134023318, -661554900591111085525774282295168967516087804834563384522774543762796747161691304816177908139839677104677, -2593300046176008282382254337766636138677705966301481430304814999145295097657392794316747952444171, 3732554772686493259265128558156419222513355893357069007081993571943743479248397476551368376], [-87229793561315748084610260623150890299935354577198752976071550583486528541382901715325611121030592886108611380149674239612190, -508022340602917293911601697711997732172160456990188009786538025721152921074218119957648674688868506076352, 1460721008106315468778897226143994287284897602181091956279580552983678874252162335870245182474432, -2845425360383746803835838127987320136451746352280301508231781483667428051199707680163917792], [105504086923113780912710406725702776978779059482622269729719934020630322339841823587209042032095176933505664937909123706005740, -7006998180347081497460707902218349080602989708987340153134771035368342202091412752161669127493512914387887, -7296364562402600040589453958055376273000250439488888706104549726526365886447676477739501510909996, -4663774348664326694939073178933485875652409204213753644110763142097037739526949133721068974], [277936021718512339324086331001605200112013031457484172091307977981289778918349674508401840947458078990111067946975753514468158, 9327503247945904454603005751604217448444259623521470659022446319263003624369801916373152975656156562981411, -9661510643140044319024812731362187857654450949052142944898816801288385410575491262340251678481875, -21929374918786662723957819356278781678338423275766102575975313941169337373718686833291772400], [54914770274330766881020137297841923076860735594327051749959423762433562971861751907099147522734946376034849592450082715526400, 11005647386453298965466385920759308992232082733487944935029722801089733006822249151018814181794213574975808, 12633260723501817286449145617557028866273364605969924249206570497781572680025039190130160622772608, 1484032574938289132712946006346080980865945224149068294503417455602222206336849696242210752], [177401272423964185347592870174566124364401217037441754084705744910492628070335850846459448669659607589719451361703014374248964, 14049290581150414659865708177197460581399324142662969655679141517929905519026876959132238812823191368053399, -36035378702107526413625544329169096877030287063782597054611000999324874740894262280803238402460824, -7466493735063419946693085643065390176107112706545201989271955762262170065559448890782831356], [-352426852409682452499381959865418701219081699027183972956619075874033627113214419482107229233010967084098353487591524473930870, -8230751836995343082144605265200686354804937619012421535487226796180856491095171065974259378827044823410318, -14861048798183861862951335897806637604108372832615983043799792425839785526123961275382860903003282, 43421457045861607067234677105754033726515952297022655888263698978609084423925419261855332292], [20097990419717463098533172788610947914185055156358032222967728229723916072262333764143655531596496759748802039349596589784332, -10227691851295326244422601908222151490770048612011079469513768825124868400297176705603722015709150526172223, -25458948623993989588783013843477575063563229013081537328161546666485998437834107749956619243400292, 12281534188076390902815201002792115192068103472651846077506326595340234436272323393477388102], [737856428516963265466653398394662753694430021028161591388531212411667016983969748048175020522471201272641194505309533454791698, 9861441748985504046025645160768707052705744045639343280592839169850362032348137864767297203509511786995962, 50190622509741381372836089549049824573940940640837228283754970452621902743364622720175123006005094, -21786669795236918451062246078512279922196763171675744607241290533192074843426517255255163964], [-1444646310897357276933289521661547679634895613884907997393594326497771723068948663568246480852390032840205704705959935710607658, -16962819103630132488064802059553409650046296844983522447750989300717918170143562759428907276539753208688985, -4342177499041453023234284529895262206189623524932116471425339058673574948898742241032134331760791, 2892731085607118827362095462038479954526264773544145657924425870519018462225825693904613696], [416745333782485016481219705808673471955351439047947833062141837626561102989562937063940317947895252449908209315903384620810264, -34643754694764204589340773883268371941155982233928690571518350443760902647597859607988203365244853653564088, -69654883010473667921541172130730383083735521103418612614680935155590940408584168502000743741044030, -598418646289945678775136356877360392316817679066238773476976410153147511856255206795626795], [11624088674934405389196069017487328581588732781460703525501788420905650608719300256812230208547537967927952977430634286544668, 30866049552876935239731354300097249057691389452612639743927440601991626163359858540640342713502903754881341, 37010599881440621912754681401957871031696742037236705356502317654321558723684666103217860136835228, 39956868066526272345725760129434501082784467410822177109857785054023753111796412647539904582], [-1310830035402654031828657086058751862066771111081556003963379780383007719569975083673648092671404815005117361582540004573483480, 17659982756418720657386427435215760966976269368809151450388455522574875355017835202729869589224614503618872, 71029040588617150900260191330375548352877130716686839423232212816356553901654469902213999122306734, -42656896441330828837932198781438131374507622003938494089108093843023673401496777324076477629], [-969985642692247881462682853492739956632302140287801861091761564568185153549185836395154948991854923944312201166186507287068758, -6293121807875278322187003543320683103817026201320311613835094717982623073328448411227661157138623853693596, -14637235223896808785426510600666720826094680391416181233877001189432852174118185580065205629632420, -5498378012373902279010102369840312794991140617901722456198063958955945815103476989664193480], [608234342523308625852648328074727155569883487205008976608125619191105011819235787160881696796955768979674629969483744956409648, 20958393650258389392376653821966706498151237014097254716561526337005309491390677432343567421679010839519552, -61625956388928913694454416297608018328290902002054831239013682805995962159649227953453599308601964, 79104609041785796970062107456314500774916717053530981333574033511652383144600905437316430034], [-5332174520750271751090271726970624044507191800513240971813391116741107337715353115145362925248826488964739926218400703661352878, -256986706852787298006646578785686260543391701218663865969644338152308823455417644230400521838305036413598390, 15177931051389916825695499501473440230232829190693884547782963809251333095173079141601557598098966, -110332345441046936630136915555548871487330735911502166989369180596401147198213847046376298396], [-3863472244632681990454339261654544159053264983420939473336354087188973563456741220011727093179532834837012837676315701271685032, 220547696383852837490317846547503298076402146842849591484940034555726927966892229180788803080413356205346824, -234385569902046821686048885712702326646216107923912783090467845104166327589803844737067773995090062, -94475261114216982225989802711289145785549590485681931972770892683895861744143123537931663603], [-5933284083387163756183066514193003149580127280801001751580441846567153144359940623769299717488403511423483350661675966457876066, -319376734090203737228005998534458090445430415232415131411903235796255034978599238485313014323456801819031077, 215780829996037103518188376500974831699952983226113570460102029653660118261579927109819060983486197, 38266073778325402678044329167634352771028518965112521854747544872822404438355655125390787968], [9306920761133391298475267593734458874851274317558604703057056103440691044169481340402639701759677671128078338944151005301761062, -47001593831071047636224335889696627547334787542082947045831436861406455837033240276251886111344969663984105, -17077849203974855026070394370796588839951904052625753430574023882647715882409432199640620387705607, 32086029034110121879189372932475102511957592311119586841974945783860073707181881137803131792], [-9820395662375275579464192192531963261262407959683236298832353833746504295538220943312851202418671079579131431833690691454438280, 716306263704210350943266919957745389652753573464107703574269722533830501680448861834485237994475906192553072, -162099220874196618144999392783163021501875204988488345921190482196089610568302251595003639732393854, -677304737627444314283029704499787098875337678057520318499630875574595457320337695088402320651], [-5006584169030049759137905508156239489394025607985817984031440591193396043336159722743455457554393433333125068682077071680292990, 917990721951976675748057007095161056027476167413732125679158501147013067535868546522632551866969247382794466, -49361450804896058084838865682973256902709998905749692884273326344114001891722785687964761522532098, 1636731644431141193245996395882288051551281432083192907853754432006261685727484418504868853588], [-20217328412547505271855741846931950203973697500120419114763850090753941864912527616772832727285108530225800419410921333269832816, -43585910748241985863693500246615509545349043974687566915369250155445329604514228961682619875392719025574096, 677983542374590986323280777302254786794054379973542363766476057401556765364535638960227704828940364, 602132254023667698759488212509449883147564223911515634463416084554747870583561416642565027166], [-12483460887187571048727148798498733558793192268591763019343969833396175242868438916420630489943679413320557620790786722692961132, 157315141201472364423107720159991576542210275894124607238960828677969999702235727627132526476510259514067287, 368588262405806477752552447567573472632177453788688952898198396103384250631058431404940977802237668, 2538655420124960754091186402995294693855538167798693285274270204642294509661262963790321989242], [-18490317070881469625699158658999148087793472420585408804036007631112259558833898367020612598874504901907441680105142798998871210, -1734390522102987723662451850893864799463847931617091743694322762451771447090782178422590924967964805092963541, -2033597843168415283626106409610906758554669941737254794634480486108722082220833108770698257486071131, -2127021882782580961593037617415939384574498617820460907493358260451034961907241240250955092264], [137070024996327213320180137171656727835483792197057419802532373356407662016717054310467718824940798316880882194790617660414234, 2733551610415206948096732559606961441632850314100669341846280169904494130091505341100217767967214883900863602, -503543651050212757496707303114995731797210650746622492002874546143896099137527562071997918760206226, -1728424210461122869050911977549105175898588873150040562737977189808617201991995709914307280444], [-22392337218837912390473890720126375130511722105016371792522486898911493928844236676510065889815597275970237352144071116449263200, -1761692748355653823119044098678405953691142934397367645826379777533606059918927827766691470770124690996552576, -1994219066188612701223652760739844100611012739132407044030977436301185285557672601305203796417255976, 383153875793317806386121171569286417424315551998149098480926396237851807733592187461018574556], [-23610220459818545909659156421263469224215249455166648124072215248065820534126659597577473594502046457432979020392217137367421272, -527306734390137026232932445491395197293100071067981536265613783973845543398013385240406409269006148122609472, -4822760772437951376281596200842162137532220553553549709793033171241288586149437204200614216595156026, 3301144269853931569558884258721614784102337358928302447954062093490743209078570562752780632831], [28858795980590996658913940310370684165332749805176776487303988280782741219095132546987692809990482566018621968354736565169854892, -1334206522966528138794428419079426858638707745674407355254484786894456882991530689158826174229653182440243555, 2048361796260421012493435667663420441209358047496790291711858312225834966100930463705125547391716984, -1852574092717199002693964060522127259203089595163722157946858466984927061793873749830623122004], [-4000151360384613961213131308451817662324726631423036244179782269625235074984479338600309355405590659494991989861975463810558226, -2882335917790520938618227701900244725712608135709164562145366500559538542188593242486721261935651984122036277, -182919005435288058616674134538495079453525919080526519203260627427358029744412803089001220287662587, -310593792705614250653214010840309334668372574387408937965269210584883537707831737769756209328], [30554171507435544748951932766220816095274245379379358692487225034500601262001315909287161917330292065952880169500108839305810100, -643703393058368556449495670315914255623032419686698174484932407189132617309453259781939269872664212732089417, 1332069830720454051213440263722785641468601959998059061789724515603345849251937094835534551898880060, -7441018565499963459921440185239422624431764369580066008399165830445035213592025201867165892010], [-15430165919550305629048493681130496860314775369423769708356559111349813733689060797312807529327828381945056123885414784117174848, -6879559150842613217848490717535590183181941882561299705518148734318077180453653864077696951235814782563921472, 4722009307287359551704988935630928924019371651584531464862575568098387137954739743162274538169566544, -2356152461048164296394214964723555238466139846779246108526893891517233653393313258041468644664], [-92012568814491561239255063634262592234109620898001968136479139273124175606211204540545832370346096633584261831440146691638136758, -5159963292347204732151661975829758165523403465570498248737662147242139687088230825510691733024434133178487638, 1679583986910531213762764092782942464955723436532109715920502187664550945427172368480465393391183030, -1679432664285495799916744795633920065902640547797917235751188514564453308355260027536916474380], [-28032630461711676489599843825460888948429018258284177890603807946813232345831507596558207655982136403014120729552119733237789236, 8393364402440999224856670743745558466152963955143869763086087140564177603971470184058509202567849691070669117, -3008632910007707774739461030010296468291726122086194591576380721004329073594374387183957527855617648, 11971492163893340537054676987696137070073420300141106280953797619906917133663092894730472282088], [-60832590098752578833956375148319671378133843967314205734526309443612222810021167183074272006761004908827884507846105713867664432, -1928842547550125437350042814568144080634123364787280193545174440926618102893665065676203893802299009078079504, -2108909286098761231239942877498929383611307369419036854279487220317264912655807066349117961122703620, -11471952337172858286561712900850282210057954152080658910193225906463282584600584116118925793130], [-128644616305345775238262374070505308030071186314131847212915097710653952760942947405476873626774816313744488001757201046986669870, -55046300005659990681880050292449072603451078289186369642575800565927262457025017619303424857143156375053942, 619093987220733280242465367558737468917410267940832491268674591604423450846324184513317394166001110, 3282438639352126069158140136174171389590178407571288648149831393345512895212614447070361250340], [27763274400145245172354374973197217092429267928402920240247080360151155712257128150434416792954064314475773756808414621515719574, 7389523431891900549464481087319933268928156783914565859174666218585124491908694432997306152635432951601273143, 6912958131689190342655488292257593592848728554116225119728421284762908454065348568948750059262757849, 3947010799539222456109598947126926812295689957663768984358621893827584419127293798062394605856], [218217663615000642998992752842114413728714365335505750246323763578080413420715578557866742916016684220404656427932800201860489180, -9192585675872041012009228093946278111623775722642587250020169536877774737297391245398786459458643297121818795, -11271740896682384635221500680912077291394457131245666885649888056389033580441142433550317349652744172, 13635892611516799178825425975394087110604834277053389291394659560808528337708573196010343456882], [295639391502552842012025810612598998078679017111140182301163111024629323456078527761826559058517223566125559292317460916738823912, -8146304128052373576520533004846747459023941519061845337416146584298876185564680246628303798677900857546826136, -2045269518611343773161664849993787677418531060816413366094484326549985836221681482927956461829964722, 12164709589263823528855973143023182636757927633730133600694194907610860328563169762955650308307], [272632775887300358077042514333358909171193036991475828274922367375474949955549621945257160305719124678087175690018550475257835764, -10235457717954006057084082890093635292541271802929040465946913401363219670861881982190753639791136022367489357, -9381808207872045016405754188115973905074207729615674045162722265349938734935983660913362990748713520, -33165463247892585081076485151176678857278547921351858056877368068966125333255481755398358674680], [447899628837761592080096393526111882078710961265716070180759136529321425327538998010731491132692776505212038376589919282306507772, 12845074193180183446303410496010636017640109339230660504670639414000007271833476369481649226326093307850658701, 55245131090554835211531248339311569836115117362089201714685952273772179616005684185871856628959978196, 5682027738113501014066342820220890021801655961316612049753684063948057551882655815765157883474], [304473372936459119122106982128323203857258588267374434665942000321213658727045850130794361456757607331385546065860111591682306824, -56835710752166240408939470270845530736029823631424356912512657206711331317600758372581339283671850542862076640, -16176712184958730019059474459040250843292140426348462890450392804627402650682121619140511213911686002, 20599271112385498209231764447242244900312631266205300060596719407235605303049443084053313553587], [46813418176942388163867447470909818600864255090663002435651934060763641220597595064824117980915463642145491244557899361247707470, 38594866346225155841311264226189689885357065355633355947974593728345594068861198708416963553270680635039404847, -16854916126605761452377828793427629586209141149043178040074601974015414027542574866153664045796002719, 30506760225971640959948681847495489210474212654405224266154653725232781395477325968709222269064], [-64515660279205554527835044422329125590121084000188410372715468003284864041856771592309515625410137576616240357195960499628377326, -36600845441045191037875076404906318380020821293533396858927446012180357380796601522107280045089811772725090360, 5750901522561574470531493531396160620837645998249277216320662975776984823578016366810771894187398072, -32133813629564189208436520618795376155195752685292267115624959191378356388724223194221203068432], [-566922532834545344662534565721655704335293706623770605449801706260047102997277146110615198213504392734016377103956956167121633000, 17936064583459453607567393009321579904326692950333816204844656066250701814973405840529098036057831417236147128, -34458675976319421021220587023385351492468580680802244819220307595210348306119247017803810020291503470, 98269574187922245973048439567880880781077034520426697646756053835072839639074461172417119383645], [976352618402167977468438888916906681527467193125966493994663878994786333514739092069537272208338951173525929158682882872272523808, 66048910851441094959417081547528819842410510064620576604224116598394654461234536015722259476392631103351377544, 34868567245626418267278176837283357154569312717655138489646756657547801094464112848682444133466004592, 98410755813529609098075105801029069583654056848125822538702022941902219418369503582288596725848], [-300851967647216901920180520262542734058273535805034464170773747791355322304469670451874623967154538601345240656386270704517972188, 8895410717173500474876128699988413553482708884741381778496067248871605473553216206514865638751973077815159531, -42560974913706495142606570101130729731849507404600241199387015915238620805807002435467860134776876564, -34503593691371217371668076795064100869671712771744556558227521331859398588003387595126079246066], [3345712663517595232044724878614464935303206635130694470468807349711042966866023345176851415381773115119144669354090365256028166700, 23063315230058314992594647712088299416378388857083899920678598111486239869593897947800927745717273016928607253, 76408474467790677130535690953021215832885536282593860628902537853549259808634410010471759467615868448, -38155882859634201430189017287113399226916732858440049353632775212759366102211499929377704397488], [-2237060548613994311999895183009330067952452233096115040191796994240973854797365338162357327337505262192768480248694932982337664976, -158729884391099221841692727794291127654056566972169177888135050199330856769999111212565378274050909858522077344, -31456696666190467481898431047285341717510525639143288605824804045670173015955196445927685022051029964, -138998592860527784842566942371706622908634494012886157530457644960199023924396023926130251883166], [2697203153704575580443320072407198034147819576120511961636337909776741252670745602597900012129342180305634764043432373774010837118, 209611783077043167478035431374553972568437452923668383082246511633336836894247912407949230152329444838349619539, -151434159956681020190802230935738292872577253475148960983952599237557821523072168604211501798037204995, -117930932435190194303153506544076743580558665834427445950990960490999546187729771033972643324880], [-5382056284647353260631848037691513255461082196662442837511811523924597067457509062949500819759293486918319881065245569872822091198, -25153022705976503528671611225341987218404097624414275562101236399225619456453360136773665345522518349477422104, 118282722781961202799765964505169718041386649253381846048509191219093978258827926719252918064211826072, 101359997565155831837304395892213128644824095168909754614499012171939223298619069110639441903568], [-1991238020466011947946400186881535254210937446340129519126185416370880705818368024824353307520941212022265881587525703837772879032, 239916312561861498848152476215937158652487446648522455614713219147219573048017088804199955651800340006932821840, 145327023682202227217524986211097186948532985947715453023323497205471473651792236718852728859141605966, -323487373265704790744624631649244442732066040892132298957517747306035488437173244938798551181421], [6339665409253832025329549938390553444602432559689313760602190308817322588387392428928285173943322670218282645164697625972433707210, -46708739243305807854018940404197736083391179321684853116970339799267372497707700731046556703023539932068913198, -34016737896259979953807636732671668375000241169803248264717147079007254594280803905060895401611956466, 52999055032779092886156679782262067757738181195860830464416627929666581881825224138127673833796], [-1188027548091022235362602772648855703334889165094803201055386037751229227257191071928332489274447901568390867721060315799072896626, 61441986392839699963738052701236489176449303681887269055893450366557797478830261163521199367286523412926245955, 59817552832319308782731288362728334674033853950327017627943546652211128767529147357441490418615044621, 265699345885208970948789219724363351755077515525375659470582140374756752262713758167777038036224], [-2405626071110097331318636046615348175457913039485986209141762808220301082854813556828430659050900490658652367317451788110535910060, -52404319389777232742504886475264968059936909267384665959472761599811165895459037870352226999445921800229765069, -274549256349514471329616320913862198866437387285860405903143234862437278558591908934321814033615753096, -249514376143154891994556470688405308789668236162181919036961455794706187222729949517975515303124], [6773734088436167350033698628490761285024706516124791609193431848472873035859886058909842023500959155855801254840891943030772290582, 83280643499683929955655254090233735840101881088019617825870254928072978063049018929344523262216601443338513215, -191495201032407095845437390758790180847954425166121623516862708857534533518418556961218077706490832559, 146822600601408553516282765028809239505702735249403620605994097723050637485303289521682682861904], [-2269362931765423536468431541948040223152487666153318853717823236886903570497631295189957131434098546689423033966809542711540434852, 30310033813795446298374371172029686235931870267292431025896913022095257251649019008801663936377750242432582569, 386901790721998902592440498088809594565285961210352506370829671603718346635615786653894130316589768960, 276624303863222450216071222673884196802598674896446772363285885896367619210036568660727024010240], [-4356568029804112844419829755482719735534058111362431971173224712236200838368637294980829919257734132451803307700514197786272136922, 765785979742321425074338751210061367337723628376554543457329071402027784724829384969177292440364035292438706611, -93148056629526568866499139234040891291539519885183856162949998121518338631739769723444536769164462179, 99379479783098164301067400617419648146559646857046801295182610105020803765651817946890954276024], [9546260603684784220704430481289088382924508171436248843087695819086355357499460351802785895230859496222630459462800786806795610618, -612574721679761764267705809170944061445710277201712603723742880361690517829174320410356124372492389276462799820, -3386756652624413781153201037068749759678293256357383086093747593291964255918733006183812666512323444, 201824862148584115526151000337082153187470512550331987885658964508858678837179207562262780587064], [3551013217320486922987114160228198171897047929492434018294282337883954806611098319411290410650168852483787911583401184790172038784, 409715661313425198749155060035873042913846648709744637335672111328355567600888623237922203126062391030445029088, -374541645579328072238457262651418367139171001579211194189748883463685087363223661281332159230466873472, -1671672638342816526257479120906742697833895102437674115046473951035779904278324415149920781039168], [2948918073617553237115010531983367539850160445793204433375568911828939729102544602662951417770898787773582776951093129515601564548, -246435031757855648870664026194113468601477817291905665272889057938006205779893053363287090408868120132654626785, -463288226399119977020414223878959885913715516633532894696628814247507481088521410240545871134539129792, -291861177449300460222828671396355260173753189381044067579162747707934893176037872317328157444448], [-22138713540450516688323832456280517645033347441306301088428877295716768755821819033004234024948348388453684901460921458534557103290, -712211415555300943636569853739907031860753777265984270305179616323991398175803782692287050163222954817210060197, -132748939085812233363359104790144932718379360264173560413929510833155660943691260628216832579308925835, 51298708983480684506873544838718919096084321624200791379795642716497720349003649560568790057160], [-48547038463227654256688086526340372946199066511640512494334290120654737287087131998939066217076864507718273106802554638535280890146, -515495833839544434049027464717987067503895041539189060552209604975281107870536334070168894978777804743590730749, -706740624181887897073367843489107175183746552259195556892398423059877009959471020870607610327947380147, -1975751492348607035827076063565581935926751986800672179256638260318643329798455320803957628052368], [14317952035083162810412581374190213098274567381134743797817509733037051308744012509748510167597404470451073405075877110772992201378, 520517005182565552815403038074239862728739888640078038243500806515165721041927636338152359003214336295352654850, -163949265579954974284852213842018207871375603787119338048749477067202971190137436364664905191599500322, -211705681149001582352089800477618519166725019413071559747664785120556210992242408003627461669868], [-22612243326458816298298861478025914853913241644677825166914209173566429665066487089093368192732978641478706626268928642748385804380, 728779023679485180327530438169473324244683603789025463305456530126919296079853370536985675611954615824420766371, -1139741229362554126721380544082508508927448898963835372436916748567755710727311330714711875048143798956, -942589362758509517935624345802506807541080216942420432618518682639065754462087771897211118277614], [-30210111402098896755968885476836980883053712131460913647558201164744506677711191188129227830722899770135357251525375467131534794770, 2942653968706105282737926390671694094522182108407354015716970689827191573639106267388510130846437378254966825827, 1600125775497529491734230653265243378585489224618625043768836794262096419406006260352093769846723262701, -3694672093285552968297643495953779802211021333124393416552841478835352643193685023530125805860256], [-140827245462478597816266142274739474994707106414905065998159191972886777392754504571337916875317842484167638600087043252989422488518, 543565106373759075047147367064006546128180539750405758021525648801802291752191806528906621738943937496455285858, 1012921463823480373509668063276516177084037887078470839141514440024153499494622204734310677671597640062, -180452642697499126915576635842195631504224430780575864144942928483873493627969462376630514689372], [-8897886689496530763993982135126589085059281581712026478241665305752052944426462741585754847178096643272747959766608188182581730116, -1120225308638291033052067002884943552456204343769734770320761452309511371283573105472467456840409476542166261055, -1505793484554316326600288321347505785870080490025423709802685762420969244999856144985624454806868963504, 2225786536750410935482037042939588619435344265483168660985262421424634595146865842977189113607624], [-88275376605185804230073862720615927530318185742141002717452967700578752241131969951192341592409271797222413540070750991141882650746, -252488565457664391505480199308898524349741870564843956731357238610583316572432730914487816222926895298816910805, -4764019391424844440201000029780228077669858034292768715669732243569629232551048061976067348717695977563, 2123016231698569075608738116164635927627697323981827375349688336726304040783226760718920682061928], [144898204216292492002130242625265031576347015672576918612369920687705788223633121231499511751832753077539477381264320511390390711822, 3345222587475138831376684300413604019989964021814024980264256446702275708603142295168928053416619457518445916567, 2828823106684696468320395513046881213009187260145864737357541039283486161057448472651709834468954775417, -2855825273972948431798340863655335697662826908262820241226698103438224258949473005427919379473352], [76346518804995830125889131193338493656936456926889978233745638552917393448007840123502583386602022552500460507889492410224227599828, -2807885966729987066005314367233374124638306684982190538817313948886766487476030048031475069874407167419081502065, -9144054766693528955521905693343153698323211164867278459478735338048469491880182171380295128739810128612, 408169628200438324491730416648375449914481029984037881207903458890610648596191766919611779743622], [60436299629783425403088739864300407247846707098060173947314540622737227263221751518058777374050129258879527628679532338899202430554, 1116484077307726638821811001528558101435775720319058265852560218040085607333458812422077714055567959594776252682, 7691391666626041348472674265549934205508515835212850452058843582696820564016420514153714854294928951894, -129658738911208659427719339584421572550731693683085826274538012426471021201711678516728106068364], [4694084234946440395127774403003052004733068853486944750838918468461497722386232099701745693923743804152139936593124144758273870560, -5720275192002101817691591929802195741325675307233492755818519214594124767139552093995198594641794194243010229296, -179690894017780362544710805050729440581878186847243629766021839427599779990881112463258445894570038472, 1317394302724928203435611158267013750548201378085296217772313946530141604141665456805057761533132], [242147761325153392981814702220722317207450918692287048816620215942117449906333371865033434434699249519522132682527495973506233139698, -6335570975624407421880486890159615018720189739753117571999278462422281814136161036806455486151307790850445219256, -214412797843590288663636896610311594674221428148730849623294053246159109518791422832035232878422003400, -3652706853711282268302774514720424344772076894456100882832875191396347980405321134027855935540400], [-77771296195560918867409508003970334868222110610611885976371324389134588464342389305284867184282006128666408806074796402597944703496, -12055376231299957219343457794184330906479489189920499588181777547049054407587442211362254509262141749951012318768, -8617789230061443014135618818288778319591515058261078656912849738241728341260532303144204525060079904574, 1152699469811572397825867981044243113266954602751275326290062340053379871169911531374115747154069], [166889094767772875720117192121431371214979650141403596129406020416324043270108966614925220603632153860226777378601211286871950755068, 13723052813639208507903531384837264337552015608872133208463705627987128206125657380063012014452781537868623650189, 10421574613049122378464926687294823465957657191684775415406612883697337934516741058064695948155065876116, 169055095632750426453922269562590122779341999159053886399130041595834680234965248325712873003954], [289029238828880035056287577241407120642457494123432894351890495670123612267814918614799350582483995275961104760272314801752281659710, -4378573469034993872188689657118377676442893771399769128751064299513613078148721133382562935231025932219426852121, 10815052581794406753787772303587879977691973348388395143619091568890140920051907228133118629539773703465, -2241967459100231160419922386382317882214024482526427551557974898626022960143776277643414091463640], [153141145385189095377272663002865202975102875675615355219175185492659219078505403638603866071481699270968320192744355309981040647562, -1992350932922490698073809778243947158971586893156892512726007752666707066571917495297773217725897412889438889998, -17021458302792659709517609888126719948983760624446855957034445246542072850801216244833850480654968204050, -19841002215381914240764037611844990386462503398493507024811210332282346277787854842265926533147900], [-746632224891423672716046621264826262909052276330046602125078070338699971946576794054021194484675434652087871464289609388017261470188, -5304639423976625138449832141069643423630207124393793820737780518032601895601489512417877773216135308038476887017, -3751015985780070786746012609681930707851477425728818682357248909430432294312551939384107360089301025084, 10352655711044051737575696095298632731960031672774203559459410371506125582627950949847377085299754], [240389985954771999803929388692855600637380003727645192123516341305407332724543466638200177997572232056036819133276437341287616140064, -27000628632662627204058372769795455434644236355119424381109861654343926799921253609588473333553786021959677545352, 29561576824884845966888226521349318182956500783849615544900417093419369584180529766466514451775954075840, -37835870300201995605484985351227746000134060101905943763147208348946349398776649513790774070012640], [56404626624236945195913897234701806830600106686074519569126267784699996249504140498491027801649127488506936375204174275336707121192, 42589827077105952458993162645494178169136456316204818567593456077026491650219516208120717463486239094989282815056, -31030274222030203363330687961766407630075379204042610855896577011642112385083374111334472062983389011882, 20368249124812392929957056293297774107614524016236402988731296334577099092303045472707273249272167], [-512788966363176620954100963383985678137396090410487775863239495142933274984141542643686292584582315089543035034769837716661953315272, 4402970993402396122662416650371444496713655852615740172349212096659782184402047645301076266311633320149090402592, 34602298088497543758265855746477593184172057635327316882128338005731467068338307560595396283878951932002, -26703202594525098601734747306181165420482379032662615077038357193332611639204797495882967278336987], [2536296210004602039745114337782946170692679360698068472129126090437090534825345726686986880483068459800838633437944126405821838294022, 54739878166020379409815101615224900274853441725076322489266140092778746819963564070982710314605677952645144827887, -19327931740045684579637100970854313081498750544728545002087859664820637135411964038081021820994789184095, -43677445390761365111915361971658623219590588428033360003080187500915472030415734352098294847113280], [-564587964754440694410572377207535657131413896897571275959944291085643146329708462726412008705024525483597071812676429240991281631412, -127915196298424047729815989888219618983431659485890287890277563002767187613238981562426634375949167378474104298347, 2453307209325959060311213328350510227037784046526844573379824363338098695211035601985172655926484929048, -72928678137837880049912559107985624631645150668559939274766257198861257145489398407891180321285188], [129807592659170488925350612195082641804309388223235877081444285167138723422462970440814611210672409850730633787088606312012173710672, -71756377292800884928678441268267162706241277926837351514269749991461389946816168060859395519611363011754120972600, -42613864243241170925242659621740211412673047995350831839901743009141418731715665664417278163156605328380, 142326293232923016030919178418253900530523048115713942307075882546635875840731112556285024199577130], [468229665656552994274439253371389285627422056462223506510051393701007065922912852572265918385292077950469791860219612277593065482834, -106227188407814609184555234869757344980035670871119862133332036918489277927213588399943114546553156477466819796870, -30911212262883355690471193126700948533393872658011471487000402001740998651893487356016837644806584854554, -33166051581959045672112640609369414674652826813879327416705192721595440064299806047702282872225276], [19294467858989005245621792800358183221922695389013346129195281473161300566314967990049306753903323263019472408240459540340058859798, 67763028884803290376362150140560943430831480291223486725604763318182443260365465664611361396830531492585280714291, 77226148743655065612169465355333711379232594691866007523823792796638818031530382169477410751894999740189, -163560119977176252826191333090032015056232258164166146772536036275138145288128133147578506968835384], [-1468960413193256305733662386364679237386654659154000590597821927830458104103160022794541040478155011756356609737239229356002218218920, 13604685445534600936372034632928390288111340310159899179809387541626172418121880445430601832561060898392356206640, -49734770089781094924635858653455169459601339132680102834232144422474762645757068564333726798828108920950, 17932556664122073416577132630449887747248312159202519914960603344514991671943432111386159224119625], [588362767031607773536008734542471701613945485899215473097155148209619655178735703923272437199139433979181432391643361681575491747170, -222324131165369596729768806223876938228009937582685982395790111159755334192382778134278472506497176988471842896216, 2892038994264203887368036401904506375784059412808429175416317356822523836167957996813966562249776658136, -175009514964822489385296505479466572173423318037915631778013509689977337512479396900223654592352016], [-4707174819481607180108632429844675942689509531320035786666917440213562932950115981964618670362547720622393344791568884846182265387858, -145979480713158503571733550765823616176270004613527086520760447718837760997081634137339041181485304995771186609733, -72628921493841332998779891989771356938032595718734769454636546971448352122740595043111663473017901210347, -53968546480488537874611957021774292185213605157547606175296338625036386753284401999157276417023568], [4132268972020855445843095502908985972621343703905399138244857883254507142532954967277924982725682866387102978027295221708178699049588, 82245978292215199955855254698295466012065307184301580039282602947024553979381054107966035599858643211955193302495, -53155355100835666595519610337022253474813241109170141741951024485570877673365092218372265196433785809692, 153169972480424591381838695574424118644111793417100059587889199759087332494742983492759365332155002], [4484621660126855309357100939049484464298204714857929721479482000169091959168731515354153762973830876543773625761144769279875154079994, 20547183380554884861787625135750341703142500593044391466873675786961660068235974405675440322279274266570703743682, -162525514536174711900866876768883781388246153585843846709716382547420014240606177332207446388856771472098, -153164193981154439999317054748934383982855779491511177557678976245697765617707099270239851380456412], [7994846380635314958356169495276890331353356857924980079584778116139967175820158626418525188204241584940693117499009869468830466183052, -231710540835638288898203775298491560041408353728405749856565193839988845204042274673915476835280289488027641374591, 68155276012145079474405833330431677238542698521610245239992732331943854150784545269882972338459416497980, 154371976164403598157508445967120570136373559937809217411405606726998810535879665427066309315152470], [-6691687324433970393642625332251217541208717990606511805535421234353458543842136633215266870759322608341106299726386908488157644503346, -214770439539691010916397969010870057618660588282480176192346611511946247537127744737640670270435075813672015991317, -533318598419756286482498909516140330680093039551857158321726057672548843448717298243614378167541370114587, 185669668557741154686897332874039242880564320701909062776747692918818128674596470390272247656732272], [6954497553504066063090283269094640124293071050642590626504871797429486923466724079079601239273036022183431238155434235942085699697630, 446705965275504038111476718968188010684119852263766748774013399229203387292855769889644799475358645669524164969935, -65381238706682094706083241745683133723550089873575401776836460361624489440187999767874112416388678349887, -113007121578864413623748341586947648782685640785709096437123615431265276704936795157733199317451528], [-9971473796716366824398316864673713135504307817469565626899245547229843161611842744443636828946725630048178552432515311823226470014048, 134432141854526334706517674099434623246282553770418278394124930479091236314512543900708914323858118977869051230728, -270377740964679766759917750423389856757746357717028476721459516989414650320312478683770507568630132951664, 744981530211924726474065203281801323233423304170986155521289219656797391803111948314536390139833384], [14950034235668425457185672587875138536460141307909983309829588979021593961438524645482915939594213099292802277479437962023221359680374, -551856356929128533919818965661074753122673701862674746131924425300267646772183789047466127662267919933051286158385, 543080107866938449295497564484160274655131725794070996016343258393229064101862679895859601946770679144385, -289650544526144740131855700118235778641184084934914580704384567224229342212070160533364781439464560], [7038074127159420008559897778974869346416272671535929823927622502718903160529452890089891458926496344680768890319981129320251667414460, 854050369688853189534733418025390447513504325163343893927557384561862532052210260295110928736311680300694216475437, -527775546020545832660535233888232267165313621778736414555872477856368275459292316636314752651210216958908, 615102348473209672678632732029174825950761240936507585113703531922581321785739364348203197293003498], [-15840635733498755847131638539499559137521760833513673344860535647153741570873117267859818186860142010140189736073160060081624742222652, 837928136124923918191961528728249041256854715478953944068291322717264433595259594557331235591190791882790661185891, -1205624332423202364315514894205013864099109075872023072949023270247725863749869988503260479259053071108852, 647433105794017837491726812578395969378975276738168632840892156653971938601174257371677913493188062], [22421955811089783261380285137682755295390605744394325377953117077674801569604362746419422488373050280981096713457461720273623528924234, 571125792939680610641268641731920032446242765311420267619989483512079341077868047353231541048042417394775077473604, -1005374402532561182171653921257752137156903744182719361139680866360160805528897675426878114066740889277828, 290941613549459670553134328928667061931363297458079855629842026335176008788991372020670947403250168], [19682771424654151564924844751717421227957656980090084945500968177932760786992904022312321516326862700826215015635954738997030709749518, -1226278589387693161677567999182159583444100157257923097382050377837467381745092329383240832453288358714311523099017, -526799487043690771471875898713901678147708692136050523193895902723687071636990882906605689733294822763367, 186821211987461890421130320218626362214352216018883550982193990523405390281896076913930430181527352], [-2677638309414880384085071280858346229506346695107885061179995009421320971415792418022005714487096080268905906504096593674949896796720, 697643288834474033292103658881586070054835569436265981471224664157223984275858415368701210184538630474203062687944, 2280593781362809231212051887151583773552770227616526674681641676119321103206252672370215027330544545737956, -1175867901718471829828599875599782545040350596202439182518537602860851140845517346303559735286904486], [24911028023923279472444302795358209209892666848626091981805776333054521953261184088706741543470429192424839602963107340377293501333204, -1610099746667581868109396084629933890050128417955662691008247603646650151221946695342378617680400040943630939104789, -569898571853416912176647079406606530056531856880610638963924803361546663551193172911222193260438624284768, 1780332734996200580336011301335459278678349306277119958036927775262123642162143951087882877889016208], [18992803209874779561514267211921021491605621169075143838496972245441901857276864352006596953812520781749487394346495168171220602126812, 1409872462746624353538026724167906384319045765217577619457865384632187665335840869193206140420531390428706122010021, 666544988429459269589504194624625186431811926574244933589880298445637249570648064598901545350857100422852, 630849718070928188171073232544139475887645216317266132971127186072842052644229243373617568411933738], [39239346513134325177084211702190757575761296049254213182621723458982143513084895755506113563806965772464105242752678100872856562444258, -838901977676201835921311385429237062377817548902170635994958520152088750914715444159632310713329018442125621888590, 1169588983394660666016078734620687069371783795367037929109489131669099189633104411251015559407736670341934, -461387379927990321856064167149035060807614272787793574790610717887733497316370850492645448162176204], [-19248771489680588487709029073801920905667344528683837358172946169442897296036178182744462505094421229921192715783594569599329016661012, 1788162014567343577921842881623586794500519095296038704181034887192146808436244186904707206238919755330878299246729, -34225864249037400420407092011233823722963481123468473543397574647707266196324973798025571362212509634276, -3685180037357354241005936484449095200005812530647174973652136964608534954538072618266907297570444794], [-41269558224784373251048053564359354391560129426957583404069125289968199778151563402224381682357475084664988047558900116967608225677010, -2012494812908244313618951486408598976215811954934458510707838847462289666696155708736133753430734785941256433346273, -1966239130281805306817359052333785957483261176141314583829142958985681403983016204314996820101440440973455, 516999460871941390286706683878941089039138361937098486462402117226634874085789945508922521168599880], [-76588320740677632060384898052141986039948731911620173709521674233861595547523871358093593937489485457905851300906063826098127689353480, -110596440193424249537359219180316325254031725150413587401457657042581675378491259650063481695977296527591988973032, 3718474133212374808930255025971892164796276336472960883477869545907702702250116566594956379464363251038714, -1655817479973329636467364788383727635422087353225358272901001972715359923704547713711697029684478559], [77376320571290145509296733077249891700003883794067910930545067201639976778893612963019484292195311227139875168971749729633101383515334, -2463107057871338896380628547154243686129645214208174942060636498159129324216302466789029085170260250255375680342445, -2194507653613672161423526864998673739959500224291585621305023754632340790698879678627407400069432091330307, 3716397906677200483816095217265131688884989030078292994919582581980573675172610437383827502358850392], [64692187764651462349225309437573468730022586045492969264524511836962076465175266677641139139621476446687153675270640746652617312009744, 3453846624117749076023879737931186548804483771978663927710960970719997199682867952299720388540763271236223916955400, -2556195826077409208010802803972552699434122002472908653952083314301136751992768636992318148048291390920172, -6142873391771968037369059880771729144062352651237742870594748925493738991343406390104254821130569518], [-170415669216332403894732205585531609137096645232488917161067163360774585921104979929518268374966451517733375984245254696776823124223530, -1389266476589669127878919667680818740869225923292537716111560060430684299170601268532345457596776267136463330082745, 5403318450957880961150710970970597401355898871033621615598135222594753743192209582687130758539554661729225, 2756089399330100633525986082654977325966592239077996589348697746960385484136475190964236671157742400], [-17217571722957416206573975538917778028830142966391453071932491235176300103021749302320281561439543616435918555456693640891207963804638, -5030060211304117104723744611891138075579679772306043054658627832677967635297202212258285622058763471065191243548558, -2786765119891080642283379372179281287904113488087918485665809134322282009305924396018122287450479263879058, -8219041826491549226238784479959262174376890277362011052820111072189690082326872429694217025403463052], [-33985304069382885125989348830905633234092088726904485779587044784712162839803969022081401871808172476406618863976609676543688360828636, 685031384406279926614531611258262108680462303527765043265729552545633781477688713179342080053605408155656919218491, 11580663098744684201009142835733501376872324801580682449439677435377576274869262016080628324520396034269340, 4021785999495311282767538029648414263411601687828013620481061783797226433378498585937596153802074310], [-16799949756760772724267543492398829923335694997972967647386080138139612072046916992516774955157054614677471413024177005420578005085912, 7545348216460198118501223892839550164366340210869881157074810772493829606358201161720548368191950871734007268876472, 293876910523625385939485303241708576637707548356738628897998534290915253150573946132007849924445982106734, -548760702965719953179737032841299361240397099052465922666911613078230773298517567627176829486849629], [-115145590269550452084760912002838595287658664507539948604736193219885927422597167681958742926017433351571341457216795951189484617287510, 5423355198556800945950896746708835541090801329283102475178458167175973182446898264946474657991086339961168395850050, -1512713739959470633566598650055808665121145049176726733637506521022701733868332021550135157270365935507810, -18278864938133416888954181076349007696072265239576752102647777304714339522456003480668271161947490140], [-72812550225907633395403302441297218941057750714268796492919186272978911660919814485340906630310801112613256933125893472543342260151500, 11802575591889114161679927432452752383445923420716294823182117953560613115149494982840566448890990147425587958381923, -3346875656445964073436799710405756991899141624469251016961074960315037292948492392908369236547974411939184, 16365799787237072136779432671075942954871820361831619344851728702177957468371026878244930622084790504], [217867473468868570540210066907584304877472873522684013285334122178132859551260656213028669846653305542806688192030759537282971134353472, -6374854168841488979598653095751749518333572555208064551941397418961078098001506000284086607046858804510893775228144, 862837658124069661698069489877746382639301204336323904418923568562438586723834061588329374417624320015328, -22062017024316124731069619621794274695688008766582210399714041048327792062099831578063324019665020368], [397105485241430928239816606964227380417972804051875626693072171413234390298115269066361391124949903488401098857767738237377099696708674, -4934807796226939230135051354618760946803427567258125135795879087958727448141496059314635721316151883944380468041984, -7281432895568183364717576509965172766074112772968193125120942597674969020969100631462806694538917748430592, -1524774469169450176638300317306726175624643351296552927214325650421711398830376325026074933561474048], [33891266239046500485039335760354282980408928341646394164946835255585720697607349839122697248203910488066246590251527850653104576878930, -546530768158641920919478533082093176143378268591602479910056695885938329192447425386679834952215716307595434218096, 6573704390867916097713277673708959954038662841499346431013009061414938993763989096327104782723143546358128, -16329856801124337530897109772417334664656767307318597374507561771394665877174500011920451601891787168], [98104786254899347679700607837755168831585826610088744563323422570646833670477556678518324539441265564453923328650644626047472157036372, -14486255832807746460750326244216036285044464259015084881351313188517040462607941383381949323553916592024464756741397, 4167950820924942600454151250312472996657928593973192920066103840580081056831509345522328810410130307854720, 22272389729981679059733300486071584310565694830006846812494577380894357764106584683777365393283644480], [-56018093221011545789889190805253276923710796075941126496020814688201955478885008779500763878630631248615304717769804886203400416484902, -832064874039967919592463008920949746312292697706689843422737566404829592901227351811766184734735602888654088503388, -7860977717046294668387941851366977855982868016757685848370016171856067582071282533887535536577579912775140, -14128090380922583471190646828201533701561979923132269824128366578761827256377468616694486695113465960], [107044783832172185357802603461348348818629180336951198164820675990829682596710205091438784315089857450581534609304294140742397750140062, 369202227422932160136974685848859234540391040503746434406974085095598355829356872970662689096867130920027262662963, -29610016800026510471472852915859465325761990073693558342096798789842071930817175038116505958421136129854947, -15930618629719201286058376946701383655522702757104162780561752158273288210014146405681271468334656368], [382961400351794496519218053315780793887974718309860311825741579787799695292488864042273760292814695270722341275739441983672355336854624, 18232954856521305554436154498205504845008163285974874825003171461260788541158941532396396693098429909959286242229232, -46795461747054127983410741722525740009890303981639263463761045385049233706088366395920978260676930905636168, -1806456361753144982595018902508590098384269827334468782877824516109773085878466208692887642325893492], [-446418087670807312305701147733653804555174939193439151026684479860755763023790124305374372179444178485813483481740037609725323401197846, -5929979609332710251090445776024851424716314613152348052253277222129325619352476909903063137408927465667125640648764, 15016698111586767866006177468390327681260775125687364172928804934504985344134094471702472776663515424393212, 41798032910635609442881795951234580447586366166602134922946498450458864159137771197011541025195684728], [333764347562791598374228110481399885358291060578455156112646890915588492494012261258394311630679900301399632281462720978566819620959602, -8742552764924255700912462234150183798392040629906414824275112658286951470398635641392361774421372449183180420320150, 40167838512677333127062838555064206351298874553265973871865157428705982805155540160042795746441360884999414, -53761932943629486301488378290077540097861812300380181884088344882387833870144079700276567935559629084], [-719252748588906808364010565743852107334149603311983225921276620535573002022979907809371265320571316398512086817936293547903903806409340, -10265635633053653999956277890330173246958867671091095037358967393882375892085565321208715847816179506924646781652849, -46836319547289117004604361573267047598558706930985709281248570021228679235044543131168127290351162731272240, -72744507334963396941742229326249101508339818685031330158477066316400652326729105092838445623342979960], [2406022244519402214486473293145459188572235682422765391578236969531096389742604983300524475742084397989690218455442928149312053355842204, 31063568293323941969454831155838484889169255329491352562332711980945271891400443748022546985832339334348987974457965, 61152961659025081035593223388546740440184479341839623385593448216127915554233882908701819821980658463733260, 72506531271667594536175757784733063064230328330668370515344867381548442743914719525811212796110471390], [-2209804764479901208664173318368171276117902140896183015919389202335856566665551946732485956149861859921073149597049046517375174540516192, 27684471317476354528170473461264639348116912355773146991689389629884895428849148392980861881058179778453721694836984, 76023999587183971293684432193140652632278638651622793122479463556303080305788085386950667762059822396831968, 22529127746387529823628332831218758934741460059628510471616926718447167532285806899160210491514862192], [375571739698692928244355848981249918282479112614521462985930282007032746821950589554552936084200365071837610081100237969649608340077414, -59268444633537979388996504852492340101360145564513095453467393054138648696485608332483863885468081013346413384063433, 80590516754586115712132102981296373146368202302735365973033466725205127477040947841310263475894961956475609, 70644584616304218901962817915723070945436633651398077005389080772292175114472170972057968120094132496], [74430867496629821684434650556463656738701192426922480681976811936273599840208193235453846944236227861881783993514689157603675339056622, -44538873920941160643975117735888493053063395846024309191034102142068074594138124519559227435502739627270072480207433, 127908715639588285545638049058005596966176047473305171770722529861919210953897932210569374195286931216574809, 139781761812756510064308793292115912195988291018126124031573573278403992546257138643153146092401457496], [-1078243263832247875465539102235191918687727223168385633098701796875480445196223659447060764112144758524140426940395987704772182584771842, -156918987522999219770501639183219732727127153536424170803483373871813596450511610697208450714129288943303730047888485, 14975861732917227068461199420787824526088453178680887623294565906314937269817920215150715301233102398609717, -115386340465078360869083921352365165922177302454050414919429863320072739083747305659426395257831813152], [57122672690931945070778203380921584996754550887043465305965722504076100087965122251800462461166189798735526161068668251977502628712640, -6714512125626010679970141517864312002830911868520327436192819372307030004325087586429551310097152352593441697082704, -55504397525840086764797736562126879302928132222993385811377415054158768329014822708825305717879517275287008, -199751833904232806085908008753215123650755883036051756319496211031035218418295461867774847213976066352], [2341769611380911039710339654683539024179608370488498543037558312675838598760347074982989541735819520280560931043874946010822318174795204, -61413146045643218050653898431786723498718085510598292590498018412677776163631330457511673797115817836554611831010149, 13201334934180179489581217564934702121837219984558979728201096709909828589242110543144300322478531207703508, 124682879612605637995236336970920427602839232433247257215259737715108550270765424854867673690853374802], [60228766064708741814923546618217596346461040486277108518351885293386020938174256685507737722126668742039790577259735555735350766194892, 263542475741331124048395734179878466707836789652276524200417616995249430040279782833709757435004120527304461053822093, -70662132024649846570833340092015610445734480620625832265540473168365374825336040482086238976848298308120320, 114957545175423123071620489232138988763135195107718852342926648366613329886140761794229117319525134720], [-3136476037158246472785677736627388998593697793497454644533004344205829652429496204400348219265686584006111094573921730143581087288489252, -131703214947065676112476309526386569144129966748347097445153792583801667625351730477492252362802671044305084193162935, 105781682396487782695929149992076653315472190775674416755733089272276152585514643299578371727664215860837568, -223051211074984896977310161816283609231961805380598222704931063620711202858706884453922626093814133408], [-3844407730202297343795483217559672758802824573573002218033785236243592087649287939952098904069753856436201520533267512647560113421361890, -51817761602946669081902077994794557113491545509736228543850437681538497736915148934598792549718311043468071197980661, 115690476881574921731205312567246709257658251440351584538447352696044572307083060594151506222926174495335877, 321453664430194720445487713287862775093816452252029193111916686391531544876495819419420296765121345888], [5288932032949315267134486467574053581729771891200563126132671262597206538308192400139582780069089168004023852409078578547081316507064034, -284160751603588691647763025405562082227741863942565930520781410062487539401644592417423162524025708292931817147658808, -53515262946840965651587577730899865211411837821315213116449774296090807132252923830796872824816025183287880, 407197871760469587666188706269833290012445584730647345698656347602355228586023132522398723347742702480], [2520386993845402214338803996176110456175074090970697507259323822797468922156393806512869751124278317134876180012425630037697602481270122, 262858119028849711016905350863993616201830458993925692524954324698505488544957802655346220457419809906968364047717370, 8135667889554815041011060336354776534332975758620716613211533481052613783726903873261570754712352484882534, 288656622129591420109435186217776960419578008081579764455937327854134688012539694648375564531052755796], [5714590091495281332664804455412161285891300020795310362097425869535272173302322624786915998191137164138925528241009084025637884423480048, -125630744153581931302888789246141327917835141850498043543447461069720354126297440222938903716492223449504502716447688, 142742607720081589878882493670062603333884706081966403815376636584856916630329953353622927072134059095045740, -236802925701924607917427526385660417437662638187782681992779755342848380778623313956278630380907430290], [6041438365380206816567153058526576034588742978285153621765703713795892725494767011643264036766734595392874224834127453732866861154138294, -246211335520697141098818599671681042703981210150801164888464105348524341750419228123268204708611557638917883246042761, 417692535086822557263618928498115322957986182773585310337772602401909885424773130391089619163441936608618393, -247246713472141468301111713203165458874556514315975802197628304855806429851130363996791989644831332608], [-1196676552491941266646145430902606252085130820213534307547239850628204995553970399863048756847331628801827516270995699114831166392925062, -65261263505010252217553728405631034459407149867045057793354308338537636007275410921767305740998963737566330634983868, -135994710509591305708759525325153080772143067576288568963507206463156403693591859166324366859464148182505092, 709226638820771355394747180436397632661976980360794760442385738853309663301893055949337881799983796952], [-6072709541734967753424893581849651491421747245557438808182509501836904393170920573988366479643893041827016996732075737452207606216909370, -109691338836576111264133269742871162216673968098803507314604181024613851531929531221978061532676023206963068209155997, 893545301533796067111992750684066999042663745402380855776680070983160269190575360907257322055100216589901293, 10629599934167931088879553003542325372257732809108221574664401607555285287239778872825291649232484792], [11912508829366325913074936650977213886587138511435654578881141516865536044231560695835712959535658111828235711285870818750001020324304392, 420259605784555353092090615108817297288440761027637504912511437947002664991045150798117318275246268378021946740864896, -106011261634756300686617370470720584960447935514777485901501164366148413504989436684076647265518820630394770, 76934815160601949243860616291302304645556374544532989559193604122459525601952058541440034485490448995], [10989718869951069530763922681818387091688843941223053661314672363699016963789742848520735106991237276846232400285077476013420909998163294, 551552130207904183063918127970491812172691284587935317391433364033064847853913468181527918353461344544090590165165567, -135083167673292775653675778947992914488626310437534227180253052241018152486940589995012294469438939652659055, 14713024023113400796838124593180719403352549136628988013566923491031287399927109641493723308791558680], [-13290088202579717535129030679412088954260450980277974772710610504694262749969501578540786133882822987234828823576623404313083253040190940, 32072585168175896744185017978536733606434967760682183856690247368230304918731219658406698437110247924083016842604639, -277426358582195566310278016975937811494611072904269838856366127416110397701147944286390162831968972981629160, -792933841037326655297040818966595987872239007517853602941602068624633474199705199177084076906234854340], [13543689780110951005580243585712799211345205497479517246674146496772574573261530014782547257324125684977406844887280022318208979962395622, -188308268874597930218821788361638355650705607835938457734063959536025776495347511996805163385554834419929701096787761, 633065967960765069373252313244109849271038250590149591520876159195594500051961752637527098885291963107819201, -1289753820174131290869797026688395413578374425739190383313608472815409229224321853147539814791555474656], [10939382000407535506773131293307327105651923003100795547325100433182062166997075991852008496517364664649833668769274289268509333442700588, -304694093709741682930925144969220772968975406927222426411719744088627447983172958126079005757549546924305730384437415, -660743656921945469944721359083065751074490932211255840067154306515012378351918511448357755384376249013851396, 247352112779226645739814063644319635499199955963981229194758134729077220604445982381109916425214534326], [-6600812766384726006420435826943638854471254761010943767279434313381040455125156437519505403547224779651217748362122915489064549571876048, 187516176942763211415710854019124343063202482837197533874736882942852854621963203239942487031309497649613208547099360, -449569240539017894225990110689019500732882512369923465364834365214155199260089256581832580256320548117867020, -1711514961153159543806806535355818419017137921270420822727469855518376421060972849269461898811842592830], [-7169956183221004996746085899853154179937303697377589875696811830097421636569360988928005203372897720363353996083349937382794760013564682, 10491351653274890497750051181300733774053773406852612056508711481443858830140552144988231690884321010409624001102799, 909016190620548763294014122809788293016816008796446076004765825021320069902692816942048270902505896432668609, -21911049417268047778965006783215660480249752766817832654389623397697166198453908868848231744092662704], [15759533099400521304536594074691647222976433559466903107134140678021394572531533670516289854579547634998194880867637321000175077928246852, -266935500569787547183188747810963269338625489573076119551595605887637044948750634792279208173065871496733930164218441, 448139208954783759284049904826166602133192657194600568067859140569665871748267721858297679931426330811757496, 1507066585724292308162003104390982717122832721142341184773408850495034668064411752977020714295140075724], [-3142862237461417123103184382844280917377725792868787481976921798220033786749574646984834943677837264227529614898197612844149395762037302, -544564768988862927552443819074631901377671901086531055394199745630785597494154280124981809236615984219953799954757276, -961282816418472840253434915404858562184849238927887829964250520202779226464972376822879047292263381342548900, -414951677871814351484415276919297419080064836898792175832335052759053245969280729779775882967520918600], [38343249283689810525327482225750185801011773918912230689606673134003620633835738660988166315831808921457967115616089070485284139498659982, -1089770799624538577042642387133182133558637187672253119183961793123649104701332520808544206984328349790744438247959401, -1714215832807625890952355547213167080629730864840333193929771882722485919179127112174702170662309699628991367, -440275314406063532957808391777910609523806762992966569851489362171194397960191559341598505750211223048], [-8247304761699179913370873974346706629429064653342721181143519893990171646454303928734169675063988045010096736380649582736062222422456496, -1623112922275679870193553663035392645624413978788994086148259748236582982097568290804991298095508330571954362628016608, 642679349607186234564659141422960617187118423888248988430856259397588461982876449429875443997467805247811436, 1496830767748632947990484467060710295737222385754894247931821981332145465651441531962413582560456924334], [-99168498840078857888847068978956854596036055722881828397543291665644627495045100006760487743522129381395300688148447077654520332109039850, 943412535608633134850389378659773525560767268915502748757779610350730084701261306600908256162675004531558681256621231, 383104315351642813712003879484638100789962779376557508578748764478444638533403629963239841416105076514306273, -277067991398130247422594180481086697658423191598248125927216399786009548646260191894191609137148963088], [48830064648907292792216619012348921286316094076083504276078134822336736843474131738546667865937474677251179615775306874080929001530515674, -441350119845824938666447303022229633926620608040838908942160550753074767358853268897275694977253421063251315137482870, 225924526282044959940941753469695130981454557090240136287496055288610345589294643935363869653500211183252438, -141116179712839437395882899450529489233898074698118045437565029375896746693480191340492309415813463628], [41641634456466876136624272537862880854412400560337358274451169762191358143881950835637964402777466976131792730868916977917644347291532640, 1204746134922898151637980008124733425386831764056155698154677215155762822543890638571294343863235972635782705220365616, 467646175298372565827821060925174835298902109859383349631589155841151176769930056860973365994656868709858616, 1056814142780638687040243882007168441348497322576630001040625633355517926082095894148077368343833984204], [77473520284011676644192700491120549693427589622028192844293146846621296096611248956936408205307389900835218997260976281618740149763560812, -1398544824110910117054225859527225414225224168282246580825913090059143955115409459053630472148373917408531250485129587, 523304364961806095289607515862373570083071517784659634665943469287001649199016798506165326423493749724888216, 2592600703076380228093001127558551078763685022220528210310598608847025230936959828590746848842310321404], [11879521447281490158617713485143513743627453522797193092050365012955059460333951901886045471337195604839500587067627373991657980308821618, -385393194382259883209945286290473307809704103302134417234524363260743357391631044105464137213820668869909750908753990, 2963483487648309750429468833337467952935766628282477624124431205493384869371226744378417233999316846734449830, 1776266023313997341823749596638936580272641552276342781015580629516815075799066876692577195277722175620], [57207743868906991239525447209232458270730984924730632947302149225277007050181438618724433675804264904020564630128551853141315067417995384, -3084779225853407279259700225376691551626619186633434378808150723521800007760817946658745278497853598075099909592918040, 1364380985250305449686844713380808836131083221266891200347812558699927547162501271014494256907223594917253706, -901865927537993482532080359137443556009890919247102855364602954758879836720838309460155816547704348311], [-125495963485167088617986653800027791171692021658840557261999000487451802382684519197381474311425903238212397904886809386745513285375119802, -1276253192212285590011547650756459197828679363327323934626885464014557724075735653340439480888512910574205090691375797, 1410878090620464666823390865306264287985033373730370882963441172428754119381239110837660819220546103932916357, 5366109442802755618044694494422244837534010080925343242178467479732651338502127026702461073461614348008], [50956895682590018205666919220100103929046377816525928051952463901706282045118392296344743651347112087099244362189859997276516272697321482, 233961454116505556391171691215886729903505343143985961278868562873161771989703134556518293539778445867443318470014578, -6188205121852918481551679353818279195609315353308732720782009031103620562097983403157653293789932416477053330, 346764020169642700011327583932407001191208751093199223800955727662054471512793054689125680110552499780], [18230791529958739414877229909176630802534688119817556237944469625988298796104133445594868337026530534893228155221509222041247239969197968, 5556521445986619604590880518774504036657102385637378562236103956027082279084083149823830433564871036671778955693260936, -3248275080244481016145118453241241816516200665238138186436435587277163484187756003067359921164629666927626956, 1755182675710619697407323447495909848348409997440320455462859718951532034174329160848646301781214292386], [-50721080033576224641479370869616467335967648328223140641700490505402728100605375928080515580679315089523425874370281676668393240011197540, 1007115068187529187500738575963945365147242915008316302386414470637825388360272642922481165973770126503130297754182241, 4879084904883985383073568656653004641524118061045850578086205749842495932048011427979637754650989629080033592, 390595082709613364790328406282203500867835032961533503981453225499536628769235848809406455602546599948], [23090303960063916180868643812744124304934484732966961946179572976117937173966999112283745899463468885191578462443432851466668418531224228, -365684188304388315235281274110714211539520861801730445367415299685581669723876543288879279921189765217263430121108041, 4341892022080314875786565199384711443068121778255476063543536313573037593759705320323457267288902028019859424, -2308553521605375791497680176321179458470512433198898569792170918384912312824461762895921745098100305744], [137522501421332779868659698805871441149300964931272418925513509063775426275279484010451976627442636829138440751617942264541456250545039914, -3984686921575768722286412814220201637340122238962611218459057083572391343729590774708037153080678390562548940911422694, -3540644444680902888697378160246695677875678552487872495648639108813629080377659380008438495258902768948369594, -1643299479916204234022983399111897404260705373188728881400494053076249326619687150152590155070486688236], [18421539784245170879871165692008695602407715482775122970133640915653205457957731078332850678881178585996520338665715808895558407402800878, 11424623547948846190765116074461621908308320475999458034348133017478907624701302692282882062267629118866737468227773255, -869790013623349168551821519634044261109305244057920527556948565665402726641443367426314957388148100883498295, 3754054120884908930037582060162588353193371431124785495777499729808119765520532992690727284485655755320], [-209739174573755981861028566921102744798692619189121998720009012171019244796458800500767583832788005510235595576598686070578377120787104056, -9326314769198902659202085811332704010602147195503477652898870365822938093253072492753282123154924628482027412566001040, -10271173166305725246276902304533695455981541031665881937432810063661873348515070677186862737593819156834512306, -10589132393824990338021531895653323039862183810619798989898916968929691168407438137768335385236736692589], [334779903078600583541815522713419710125052346691392651077246185220119084191636772687574731325885015290687244419615959878489732047505947482, 2583282610446977650627742702236206105233180701298682073009261209911473419378066307465575987877545202219753074785367044, -1719083432482804499040516752581191539857797779197100659123625588074043660613095414127911380264556959660935236, -12485920172029082875260177961739664243737267112929238265388608224459060525793500557145979094691442142984], [85164048472705900044284840774304797860068690964751960573894864670638502467300030284387552212293546723595564695637109852470847948514487012, -21243084118225949499687288186391422324898765594020406995755690199013435498058251019144006223124225302201397882295722845, -9612760987676807140092432014280228191936452222235114459096170334686298292914197556300159629580337320938548732, 28489623230915409253706872127399994586143841999688843705764528203682979273753729599455148767771529636042], [475427774345882679568269042691364755389943486277990438236868296062480845420911186885794806848347889681109449233255152602584377960165670380, 7406717872567930289795015581295724291223862245920465987152838763414935867985151027191140826024828944588451896052504393, 8882030562300553318542870827084364248270688343722519017493166478517851314576021702100443999008894843646939100, 33306964841747440969150256418511518890821738174568651118721114196711016497351839343665325757084313336550], [-213022295610994314067594056314332200835852624874974166122010165767697940995752059434043647945187824194027887284311911119501422743432780816, -7034683135957545897684121287062968082114065659140226779999116978063760488218632717491429379814546072672394279058035128, 19417876424157966280375886308196799398195463969788844026762942974452240009323360621443202107733182520123964828, 12537334718332195550282793783817611194287097541141204829470445809056264116045282749558209560761887994982], [-271166966266760693544711383385258134539543806478923231987272643539215436636499108150946485966273416002525117292330782339806153277867311690, -9928815337383421549053828013597568709585737583698693725914913722827959680834841878880171552385950310465410349446323173, -32414212455322312833496683943999997190252442518747629783797872659511996563456097587768283184133657352501740875, 43832019768861339138772809581460273118618966024884724770706016017810810097193152093149224481391435885400], [560614505257468835155506819177251656363318329871825973347999483570185934722196823703038167302421350152026907573790109772244881344382429432, -7756176747116612492543082806360546765621180920206520039923633459512363545156991201475330923235278531770120417469891888, 28860351195801953170844424773938717297921052360620415152606009515220471305580496140060509320683007885070977282, -40994910424547155812061587940597945971991250676795603337228280235267060115437375797785961566169266392267], [35549627037718070075380374865610760086559269379491101496523886350990334269341872636172299992441943594187080368826167760060123340905783358, -6880989069438050321138378934830678587756931198086888529061910626954805831685475924247551683644071994205908981476222453, 12848173476854806138258741128749616997283019224199901297506030743154208613122973092330650229941856391076912069, 23812176959756991399304168048162787329650652245239000399600959908280908901289175423558296860152262963136], [995032887611214982001215122488995546325476404637930873398240524339106149863886583866403303890552850673109019627523478296722258433290860820, 2337111616906236107646286916452038740206961837223632641367099424500365786471891307237288744410743941601699899719835619, -27460859312142794541367325519504591054954645569707887750236170713066251739562658240486352451692753709145073448, 4446520097065722686466483265022822554810462562920304192939778207171535596607267103568176457445628994588], [-272515246708446043316345636094625455943227928637727861383307078174576962198878107564457455902032012644006356546623921997114907872644835808, -3731610061890440432474215173451993587396121267215616984349761233353346719532940475330146660103309792851836218255350552, 48526982585285762605411074799045027518626499690561941747702528569705385351642224087415800985410089817643020816, 64792017101029668077491563216344835840287218899234887325061864379790988885341528773255852336832528499304], [-840618456932353926907499781892425208672172000347534339315722748047391406502253112626084220334914425954593995335787830492484999502726302686, 54311509619500018036423646371763082195089254481750778090912733640151199307318064739563279856755568325738753675905404512, -9257020776948766921359805584122826166215033864645028172708889333266746732452201782138878088028535056612850784, 61341573735050766995309673009071197062962906265165793204880934326594527880608982683846367914650973009504], [331527501093615237204883819257262661711709367993420202582338751427075006449149987964613730577006278668815010688433370237597630221458850610, -3858334966202517632255943407805092235047338149874274553952327536160270552587163261098896861368353315799103225265592790, 23568003451196427804624394050031814656562275786193357500149102783345453831260150987835261634716408582513948470, -52999999888936802692037664433037445802139715110799746902764073097023488093984327041219985236460287489820], [114308871154083951346111865695937187028831438718645111207103932822113460505780175631926616211704822803035954993565365051969994681725024698, 83210621814437298770275875569144613061919016492987299739027581472184848710567934596289343035985987193879947870385422900, 50013801730718418742396723296971820773167260394659747240695956793503147042929305026623405770466668243526839948, 32366861268341622602555843954096296326789191907708758246271960844944539706844150528086288393867008541112], [163388842804005010614139878149398911711288782633645888526250827066683226701632377148006441270387261719005844318500337226607803566329250942, -35663048472449222432274652653905805076915891414856982605563048672342799371300475232335597701685329652101552100096097909, 21735367646055305653596601749849605374174596132585572662783204686035521413691855740818757388640983708634987589, -54223695663739831962229027116832283477581702698468194483438110460857063013865920531858085309302445915584], [-2539804830946330786690607171761110259016415165816642386545595663687429994141517223134496810353919792900680223063023033821075788761908126006, 98017872330735532207025686936748193255397779049070137093152346911900500368665957834269380990045446429942127398479376308, -64464760380399435891137275368863466448399715457069804608352436067590644711833688760647341875621988987482453748, 87095276460472245703029383982904545176912335107395132667796938021456985518427578395195490262649344082488], [-2558462020371589544395447698573087156519928728480209226367094514772923416193596657216132408895336930087941517391540399904142046878343443112, -90672421603401047809764913807472170037294921212498067725986734960536047172205188677732992185903850066618798558745587696, 2321918390702687150654246741208800712314879509257173809970674416057914695109009166214058511501356511966165482, -28478544886890088527855338513704454095880088863093784478196153012548241597133145962850274405123534074567], [-1921081782355014639354965109805918169043362957081103625405699895634011774478598274127180526074456251083528787614052294598569153198458664862, 131524779757519811234642917589438614752470862733791052914403602827735091359370892234931529204036387801427844732148620640, 72793248035625834338075956428930120793623437495394494435110116553428188218213554144429482883189079489350714528, 125781016645348359030639096894135905412576266379426404876497858243394717714410491646211327709236744712032], [709505896860561816687135963855961263247568559146558155848717571679542281914319057451366951824809830032697567567382183642833072995166831460, -79896011876260742260268282598564687719801353988652141034598753776786362282705657079721014907529708332331205492407366665, -84794439917792233767432022565541445413849601710230850495388512799471937969260325555279345938759068524561885200, -119691895344245647228634663828840344681013857631912934659718829695999346802220526698209025855515980713000], [-5242933182933503332002107165899779737967610480213298788209584370267388995973805943023301912916776710098061060543163828279357634901282366616, 8018551278825048551678032875962949950021165983505406547021127937144005617317643730407458812340307653654362100270875216, -89959974419762995628440244517327837386920847418761135659137414491358767272449321095204531829867025715731058426, -112968472677664400358623762604358545614101743150133691794658058441838245065094577625371498138418908291169], [355107975340900447345485940158302114793930527925944777174531723245916522238487364287928546956365734171965713252099678463463319228635346032, 188266315331300823433981920781115433290947770942769507994336814170907946360967388952329608553847965104069946318264852728, 154200111234913882595243104626247047905447796015131812333244784787547939947782262888514652354869562733829108812, -6004715086695903558541061519383358439388410478710453108592238090026502007909316510194442067733151946722], [3585730001596456691868344251920820435830504489064923508473823956048662919485037868165562493221859714947110901400055873644718145287587966518, 56317342263170328862000234489501130006130928947405097372983850141874265208370149059852565325626175406662917895119842787, -185929949537617500002859298063384493251137121418032067174186148891038447599032153577927511140517388604409854867, -40706422521149871220782726511103145814962825943391643207610065493915456398614326104929529591913549275448], [1706670383809905236453492863688200997271848510457422242104197276886201318496337903952611553096000394146581729561408830989557346023053189244, 27006477465334833639522660976336770037883708625830236581157852165132480500540479309935543851720792480234657958211010897, 39131026509690678350152385367953866385201010781026629518772412792305647363440256772012187930674854146344882640, 263168218918045557283130313686364066473436456825033181556875867950663952299614548712837604274856823562760], [-3815214488764918889341046908530207201023728426950768062948018080847995371138324338240802928893714237489002604120585943539216268748868216192, -24933840719376918496605061227551157912978312158861204495296385095340424129934788368141281534566021918450569314297037264, -201176459294307809876134947129908010122867838937555419947663527297634634676275907789067154072408988949287974736, -352640964743061334505536091842907010728977816557688698584556471955560494837895436458118871114545270099784], [2508257164610305005869321218296514793466635421162779220145830902474496216130383041960240731203644348895026150542859502705980886973972380290, -11860319882597881706921681667125475023727084870434538869312715793355865369822681338536261208647638892466994094355377400, -133672311987486525071201046121503522612231025679335506898601170291210839429065142749729375846062983715599170440, -73196612548028566878846957617771802914221973527600226519317228820687694070183767762609677077822429649360], [-2694064048878145399676109136135987346232549376534307456773599452944161720796580910473088142182398260949095892162452662492196666424130508986, -31773196179742928075729447137098933507590417246396959720911122314944812939814294863430659341912485478063942239061784109, -11560296202326749760817263508714556269925588365749662388460048847887582583323904944449866887343988868258808451, -93740691557311832450778784202382874745630449706187487080521770345221645718639303235493248251542375491944], [4361633278638749922998316748072739538334462075427876422553810077234877162686957833474447793161798920956261017686378683770029909088351101580, 99084508352027430531903953098603282963371117894733691935964550173189041880872864214072304255723223590753628952972735161, -44732668370594612601122386997779800992020774022374827524274056865818890809714041747115693696024458425419699580, 148286778952594077714699940453361091930623506895715855249706138710925546006753905264412012853326258277130], [17535716048497444043183810512882471132527598873025790464010820957091824971822950688593615055275641397031395556098330685111023007998368148, -55310556824955547610594235254444741873100625877972355693221869141056859808368310574751532444892569239582750186843122069, 209719660636029015539535885885000234870283444692637118350644973586461893738141173927166348550019149965792600816, -167982280400719922627493331248019744393502898700817647101674333174534937722749958248694802198198893299496], [-9825784942798970338459395805594323516370735606556788312633998328114969648775635321796204625898193570992676358019213292297886336154887637608, 368895797151366519023153185446299694400076643904629778087720331520565627738624461736273992797777903143939654779711150328, -90530219987395551102165663224557531467519694206715703382718356102676560384852102892973104645192959174304094926, 202234057917311558503076156159965817993894810358895845483014873952964759843492853713679905631483266803181], [-8039672863848529197995612750632239305140393728723382953929688274096433605643331281066837101275200999455499327902749304943066216497184274406, -313190522670803533252503597374076505986920774342458496781451399068324101067467653880028033024158689782787357981275741132, 195758772697165614960539294474376644867970381761070180937114265873926013756087966467634578453137728315329997964, -62423558052253146364936262422576792520130198276833078496178611907132355141165018143145317826764748992584], [-5425602396604960764869878318814979208149591543698755534566144464055842328102344092316004145298185500547231480818004484588267212715700554080, 130313986868940584577612007817459055500149076425637846672014938186246422149356690059006593717863177992006259153989058976, -239121794013059594002365556833935251990154509823078024159888719162353830774083440381008166684457747858989196168, -605349682816989408443086381874522424652087169225870335072845579928632016792114271483816456515102273427092], [18285756703352407616280559834490769755714874491075866730071051802496685896780176142297669983339354353352948363824872309495257149159761063210, -64025405323016353536928693976622739632796034992129677425796934118655427321394866652918787126709714519113996178878038060, -26243961025962403257824537024286221508504392498042901511726899981335124451934296764560748721954359546195153172, 10476963534554976683789013541411329741166632780969176131393103444429154008279755769735797571640149675032], [-7751382256288126783936720156739898337772412276418666883934490169160420650643051772028528526375994379264810568467356040262180644293382934868, 431519153669060157784673119772478842314596442135914629656337624898671409354152231040210326350102123831223412702664099861, -57420959176021884610394019311795043038969208318045767089522129994716543810329999182457025368836832795129607168, 135926070874907425684506549326729746100405360010914538410287573251105835317632478555181755872138131460608], [3061306015020787810119263121154173928233848596974902909689854215798837671892281023849100587283965726056377279593794164794669093963337378422, 539002026320078583574439331760194356490575984553281310996580580455332887145699847837421538136273451710576909728671596923, -20317914653271791962831603416084340163434581958060707485059110819512555278797447196893834483254061797987911851, -397834334733820937079651646422692800024890586154869590565606150611348701679432110834432174286832178581544], [8940561111011042693294046428239685766469250980056106083987196068224403965948346397207812521597360873653710572098066095369829607461450822910, -27747516507372844856631725028004004993896721449139461403164689774953088020003518268430860522999852399826373016633108205, 219927954130977180971806134596857559650556232580272047593825264986187686901276249119571932803349997187721989181, 615465173210101704967119705427463504255810620263918496505878427202972471066460066273771646990036765850864], [-10875993157510183117420740049523277531842102940595486570764565282961555493217270835447178547613599425732754056962028478614104427151490232126, -470295867210052828954714197153462246367255854216552110183251822219715592433172027018673621202672019813879954881485106158, -735082327272979507700718968629656759957648555089677185575823143618112825990590298285295186261600186907640911154, -188091698193202627479181132789814629830421086307456761417121940702193127947304729727598854962216775841676], [-9401225096719633947621508756653166386187974280454864781119851915943878676701822734229635308623498380486271153530678799697561665050907289392, -200549217838854182337622533777174702322928149558424779103253012794037640773806681971888090536363157753431592683520757248, 634605172189036707988914010915025279522565758911362601547605559498751903943260702360197498195158386754091035948, -186604164286000005877551858881481670271083244678553055493593174102836424436661236741037899569232503844338], [-7061672366623545961574506813124769541493641100853606557147560512472544338216345652500116696094164976043725451587765770177493559666254390182, -229452634010849298609405940359241163130626037355103975117851934131460974746590532938140553675970361305783402986491856300, 840781722535150699936518173878432034284880437659692577301211530147627933597032797194687455713662667510667570284, -513646497225091656273115429089578649083591705143357062491486038877447899025841371507129752448237697484904], [-10358257311930291352957853110257262908340864111039152273683752491822229987635412040782785754703639564249774698003640888153498525726370178650, -108541769500317170695945306729633649992467770885830618729636788512447320841105148269187532431648110659644793522775045809, 949611337770412141186247655943912699424458700434872161785084016596602823002633439179586422649454743895259319873, 809196257444108717253048861051942207388586246610816012903524351816101706843972289482314118624050083113312], [-15257879345277700984631223259725142001964721100274438639134899337798253581399938785749067708462982451959838617279461091447709617368966206488, 507764694652108556274643766856847119555086002515801988366288839348334231874377571559403404853289462722258461151218810880, 530808610603830064865950862887667687299827659040612627185047852431659659068085696748712181488984345721182459062, -1045253240440497977298148216575368397647405969290564992447966819766912085343615193791837722748689728045097], [13169698718268751334670604745730937039537334959952744913041634328916061325984866322923006713525858518475492034374170880848099251168965450798, 452942823661088800177914351790662134230529503932132108204253320365092553624527745854882951908843660978188764206056831591, -1016209758624056029590243980296915607681361116265538420529825204552918548668200116966627943659344911283942043223, -2293641509252326375959577519858284357850704045794119028803064836758557835395227615948750886333123508040712], [-13942942658237938459864865728155716205610434078701995087041489087565813092097618325603086855963434593669207819817663478714654313394290950158, 436958666214886011928237279433097689708907863587495186567468417700896603684965436758733449931960484277900655142641864170, 123743998645487581884546078812433585787404588141433224618499546066058287615720189572822840560174543541041144694, -517226162912653520625018954912729517565308498105710956141038473806622505096992719065834735433183778156764], [15328451742031858128909352358660415514800888170531551032965595552092233872637006694685850264104289789838853709766387985431836914636525180404, -708557992917969041340554382614455522851459668378378589733262278388943349067850397439908729222365824094134860144637494157, -1843173148877870010678636438764078853737096967347019371691596430709959309919743982253860941898331817821892541744, -238989288105164394800216816505013739595517812092497007906237936066155178694192659938150396232710164540536], [6361472634098221285643440196282260542360724792960969825127260350161187533947192677768073347886775343940894671103237366751726611348487376900, -1404399776315208480689469739023351025268856015683862309352519906392716258867351603962403977243169875568765642536070098301, -1155479103391457506011200209645139922841778601345453764241346442520563502560922030151029895165911747111628783204, 2247342168545590247598224463593221021306981552430928526985115172062013778992091755239681791397989669602374], [-35378690833747574504871639105839329541995897753449559229312588728168075202996024283502657941712895317696555104004713443471006179096788742126, 23981013673164537246470142192602235557564976084126682283095173152854445321706860339428348637331955141791186650123379144, -1808986472633858397557506399900831807055269498140755555265609640602407804825770437851122622432390024931368664648, 3975515435690409062353336228935930198049196046559122650080091582413060148922567418792597436551580590859088], [-18586605977901323626874069991098525699550370351629166616563409151625901320118240905257566235489308927002761670735255101824232266248804335402, -798557191501090347874416368008485097302698248527333987527355419237206837851668232130178776158105129285289985195374099733, -2492220575294988437078867748196235341864031797162716152858498312579491998105776099199938455133840955236604475675, 1693137053156170819600153242558644256814926530913539081685494424962757007904961689438872854919888895091800], [51774027836980578925774002176958563715576089690206478132839160701463752306458537526054059214205734177926359230440428138373399630601132979484, -1051953143290025269996749275008487642267324566470698926474988019452397380153901917476800751181628512435364438042885752823, 524320915656078899353104800730898878268918854785134523516606647022529983566172181788886824678897321092973058288, 880846727579133493371237865161643121168102474454031844348600091707466452853623121834206707866367410451672], [44731703362652305679958954089344664930453261772986622702817195779858848151681038137525057533235093608305835513766387699727765148630636993572, -1179369819643974700484405255293265932969455367117925283337199646769008100159459256984002037667044704327791321425124297097, -366006556589107261132085699432855623987131481847762480286655164556325739043480446277582162108438959782101462592, 2161595067528144377782548127038343388215121244924139761657234830853836792166414342133867737153167764134752], [-39037657163128370097866759595902164933880875582043115844388360230011460501623009583631894314894840166568317504059781221001648945173938953302, 364363181340369657262948297692616262123482761099178104152378773737137417470072196640430081394915730567388640222834905498, 2165029734673906703659167231555859859972588096762689145674589834390936835407452965610839425987063695749878362310, -2498821296845664583860692768314957634607615039683275841771415907437106433056406584025612905680427575756460], [-868444554901147200110413927678941524322702610295625439286256574511400898317741166675247802023157222734624542704360756390867595547024273298, -334113942795797432478384324899900617899490345947102484638514673553275263173663313500249326791798634774656192718595539145, 901613487425041142047498056344051841540032647560772062052121550877797976606284499370800590477751011371852156889, -1582928479044648026546033722338053820014457113746874722504744348744389090455536511452376139332591331380584], [-64372993941480319172807198529186036724230060746427462936421294520272637533770541940408504907062864911227207655388557362371043014345750781120, 2157067563130982440758645237538696345686637990459196364146060714193042487898715409934728440268030013666960311249751837824, -1668416564924754392846554617266096584138789286874776817521910191122821810605615914399180020764485380055472296912, -1088477623282656003073505245164124691862531458509373479267720663621138573186485704997801196435332350424328], [-35592393736945672022414005615742720887150900859980661459821990519882076606406084021215732197427568786431924621645984758962418286681972199352, -2895954962215254967771211445610767136920213581405346933520069348505175973402152796328192897096852056355731960438898867264, -545247186029299744117080098627687376170382809496344269966709816258296479503822900720071019571330131863662621922, -6645960981190309981853456200632540593890156574893368595257941471917754761231174173517701557276622262024293], [-11444703268888218168577932066830704669608405519743845234579994712577731179408940198583205102018991146656167387891192705176936863543828939182, 3392291743199046085527005187810327051713019354560776815463364807455694831408269570827618378869527560751708909305065890698, -1653552192315295645843105410301742119199691789548516342524044784549560450785827095010940779572893043991491578922, 6509610850875394524611393356740848367852383430233921926027488992457903858884558633843885277149245260056932], [77938441033343439688631462406572700365168194834148085769969256898587114915609301498647878026432613771166885949629605522124329787400866848344, 823634544233158007574276310197623210306233385874609270627691704776693369478466005747528270674237445686628415365250506824, 4413415328981800072122519891132939848023844599019961622543713121076027890815362377936917708564206742422660669362, -2820811232322978975376839761244035158883826887694880627750461438167357869505356033266927958114591618008147], [59194335487520123721940090792655264726080517666542327660535091550691849758359542432920356798786654638280742458546833336716452167558018689950, 246290853441298608382177597634569722413014091583387858992177341288507304664252981887991995979118472478834014255287807071, -3185863261504070030892081239594146079922774735970685643901807081363177424830389939082001577326549426875337171919, -2607883590834928759343933989865821865492589190473319538960893999577516907851596105059608774003131726093736], [-16927128798092073963058015375519467268995895714521094706015791694573818695119426852742870426829666331839986319386206240753965824238886822362, 3635884608981366132377462798473630765319314137302387945049956510411197122167208827305969907437520437590489248134174674843, -5280129951813102444732719302861107012707184023348494763404614514026544405696061263792133486929137874908458527947, -6711851478233048348544996253200235892255488032292754867458742197153412413040910972308817673212074783862168], [91588903801695270382034537637511962424699315866736717711810731941954011197239120427920675830891540890478956365369627542106873670075502351728, 2651052819459481646192091281210580548371887521258387208042135566780812040974039521133496305026024080349814759910426201848, -2743758615111835516472246350980555602182189954948646878738397233516300360646128335476151349309872585485813195764, 1751305260091561066378698588595590004860510784599335505312596691178588427691168634685637418214460226545534], [163836681745511176155880632938687680304196230186849032852987363539287573924206381966547502063170766767000797687362977316149630047591840092540, 1193417566177435277269553130306284072988168629489045981344596475238525799231124283342918877144580657543578150918840439161, 8602785781352355690438568327345618485348039747812031083910368570211294007946664106756891890066304004034167601192, 2416669663966346303278898915226365800792330611842879793143045040810739893060961723654735288564539615266148], [-70141846802411716371496260155861156164615802998931350960722419543453249066834755201687393292112112532138284957322635117202500751584847399926, -4254343699316876716858318242881725386321701326268946168797654993206075608793950287342660049900529923759600888569875715452, 5081532841318705444091156698799314939989834833096909713661708939699628442903402889516001192105891519657872843068, 10575393659084312272019273544015073523260146850227440640186169996051470566323517928296546057926216883067992], [225424812464629158791316793383764683043755340610431174214381063891582194152171885258391593193977301238749223789030355444218524360091911675598, -1357575359402342176336491367329964809684121155556407061418084240021652358095345091366177735553886945329035803321642822865, 6798766824927215771577678119369211420649126807415978069373068765409059522156572388319225829805499438496172147809, 15572678289914226067418565340585465803806109266178590220927468353005844450131869247710798632857967249348296], [175186872181680171375086923315293258078283835561710168677445678093924081283602311745230832512690924982835419236411917856266718008014338515604, 14748386171124565843355193091567547721519667838855437024544710685344874882371667145839627060506937989303445490438582996815, -13437786018316781274388499017504903225882038818054176303631670541080888240599720689965683408824571978300361139796, -2980000944279996852253972174909823662737876927784248413004576283709472075320739548819081752903600645049874], [142445102015739279181281031823436778889766753536384118752329561289659795414132746541083165529049720066235437793643408197549457717417744301850, -4139189148255312933279647748102755989941207623496356100062011741237977089745554706438114293576540919853785195837561658958, -16941793195734013745405145478894869212567796989046451504456203919935470785517110090290680034501908212079890997458, -2955258202886435101401349663768160428423288516320048045236453108529961797388030993261531950293109026389052], [102284088348475820388344059915188815315525113218439933592051178844443723783984261830423182307214743615668659058225550064905278585230283464092, 4969957596205956400174629022634489390477777021372041790416632656571021276963300866004233566333181053501929868183339053573, 3259741668215994079205320898798213859600834570031704470808216954429771170689301814894200371448466709551514026228, -21909209183093691094556355462896884115366797574727970262214819771581705697319657548147521548607889142356318], [-836039199287517526795842891696514283554814610940368321848803835954314927222062510614776096779425636349678743686973765958737098732558017109320, 11297562706348400899754613801707086036362225848580780300928044204654050305678435990429000860581516922206158081837509284792, 1136643875896280942896878229961215502742821730451982325198764514052243010721999131824482338981118203063245247722, -8763946767407018181550884604433700601168873135446000604577983771727114627263182703400837913782554219120007]]
